.luckysheet-icon-img-container.iconfont,.luckysheet-submenu-arrow .iconfont {
  font-size: 24px
}

.luckysheet-toolbar-combo-button .luckysheet-iconfont-xiayige,.luckysheet-toolbar-menu-button .luckysheet-iconfont-xiayige {
  font-size: 12px;
  top: -8px;
  left: -3px
}

.luckysheet-toolbar-select .luckysheet-iconfont-xiayige {
  margin-right: 4px
}

#luckysheet-icon-morebtn {
  position: absolute;
  right: 15px;
  transform: translate(0,-50%);
  top: 50%
}

.toolbar .luckysheet-icon-border-all,.toolbar .luckysheet-icon-cell-color,.toolbar .luckysheet-icon-text-color,.toolbar .luckysheet-icon-textwrap,.toolbar .luckysheet-icon-valign {
  margin-right: -3px
}

.toolbar .luckysheet-freezen-btn-horizontal,.toolbar .luckysheet-icon-align,.toolbar .luckysheet-icon-function,.toolbar .luckysheet-icon-merge-button,.toolbar .luckysheet-icon-rotation {
  margin-right: -4px
}

#luckysheet-icon-morebtn {
  padding: 2px 13px 0 5px
}

#luckysheet-icon-morebtn .iconfont {
  top: -9px
}

.lucky-button-custom {
  cursor: pointer;
  display: flex;
  align-items: center;
  justify-content: center
}

.lucky-button-custom:hover {
  background-color: #e1e4e8
}

#luckysheet-icon-morebtn-div {
  border: 1px solid #d4d4d4
}

.luckysheet-sheets-add .iconfont,.luckysheet-sheets-m .iconfont {
  font-size: 21px
}

#luckysheet-sheets-leftscroll,#luckysheet-sheets-rightscroll {
  padding: 6px 10px
}

input.luckysheet-mousedown-cancel {
  border: 1px solid #a1a1a1
}

input.luckysheet-mousedown-cancel:focus {
  border: 1px solid #0188fb;
  outline: 0
}

.luckysheet-cellFormat-config {
  display: none
}

.luckysheet-cellFormat-config .luckysheet-modal-dialog-content {
  position: relative;
  height: 550px;
  width: 600px
}

.luckysheet-cellFormat-menu-c {
  position: absolute;
  width: 100%;
  height: 30px;
  border-right: 1px solid #fff;
  border-bottom: 1px solid #d4d4d4;
  font-size: 12px
}

.luckysheet-cellFormat-menu {
  position: relative;
  display: inline-block;
  height: 30px;
  width: 80px;
  text-align: center;
  line-height: 30px;
  border: 1px solid #d4d4d4;
  border-bottom: none;
  background: #f0f0f0;
  cursor: pointer
}

.luckysheet-cellFormat-menu:hover {
  background: #e7e7e7
}

.luckysheet-cellFormat-menu-active {
  background: #fff;
  cursor: default
}

.luckysheet-cellFormat-menu-active:hover {
  background: #fff
}

.luckysheet-cellFormat-content {
  position: absolute;
  top: 30px;
  bottom: 0;
  width: 100%;
  border: 1px solid #d4d4d4;
  border-top: none
}

.luckysheet-cellFormat-protection {
  position: relative;
  margin-top: 30px;
  margin-left: 40px
}

.luckysheet-cellFormat-protection span {
  font-size: 12px;
  color: #ff2929;
  padding-left: 12px
}

::-webkit-scrollbar-track {
  background-color: transparent
}

.luckysheet-noselected-text {
  -moz-user-select: -moz-test;
  -khtml-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none
}

.chart-moveable {
  cursor: move
}

.luckysheet {
  position: absolute;
  font-size: 12px;
  font-family: "Helvetica Neue",Helvetica,Arial,"PingFang SC","Hiragino Sans GB","Heiti SC","Microsoft YaHei","WenQuanYi Micro Hei",sans-serif;
  border: 1px solid #e5e5e5;
  background: #fff
}

.luckysheet * {
  box-sizing: initial;
  outline: 0
}

.luckysheet-work-area {
  height: 90px;
  width: 100%;
  position: relative
}

.luckysheet_info_detail {
  position: relative;
  left: 0;
  top: 0;
  margin: 0;
  padding: 0 17px;
  height: 56px;
  display: flex;
  align-items: center;
  background: #fff;
  box-shadow: 0 -1px 0 0 #e6e7e8;
  border-bottom: 1px solid #d4d4d4
}

.luckysheet_info_detail .sheet-name {
  margin: auto
}

.luckysheet_info_detail div.luckysheet_info_detail_back {
  font-size: 14px;
  padding: 0 8px;
  margin-right: 18px;
  border-radius: 3px;
  cursor: pointer
}

.luckysheet_info_detail div.luckysheet_info_detail_back:hover {
  background: #eee
}

.luckysheet_info_detail .luckysheet_info_detail_input {
  border: 1px solid transparent;
  border-radius: 3px!important;
  color: #000;
  font-size: 16px;
  height: 26px;
  line-height: 22px;
  margin: 0;
  min-width: 1px;
  padding: 2px 7px;
  visibility: hidden
}

.luckysheet_info_detail .luckysheet_info_detail_input:hover {
  border: 1px solid #e5e5e5
}

.luckysheet_info_detail .luckysheet_info_detail_input:focus {
  -webkit-appearance: none;
  -moz-appearance: none;
  border: 1px solid #0188fb!important;
  -webkit-box-shadow: inset 0 1px 2px rgba(0,0,0,.1);
  -moz-box-shadow: inset 0 1px 2px rgba(0,0,0,.1);
  box-shadow: inset 0 1px 2px rgba(0,0,0,.1);
  color: #000;
  outline: 0
}

.luckysheet_info_detail_update {
  color: #cbcbcb;
  font-size: 12px;
  margin-left: 15px
}

.luckysheet_info_detail_user {
  font-size: 12px;
  cursor: pointer;
  margin-left: 10px
}

#luckysheet_info_detail_user_img {
  vertical-align: middle;
  height: 20px;
  line-height: 20px;
  border-radius: 50%;
  object-fit: cover
}

.luckysheet_info_detail_save {
  color: #828282;
  font-size: 12px;
  margin: 0 5px
}

.luckysheet-share-logo {
  height: 32px;
  width: 152px;
  z-index: 1;
  background-image: url(data:image/png;base64, )
}

.luckysheet-wa-editor {
  height: 32px;
  background: #fafafc;
  position: relative;
  padding: 5px 0 3px 15px;
  border-bottom: 1px solid #d4d4d4;
  white-space: nowrap;
  transition: all .2s
}

.luckysheet-toolbar-left-theme {
  width: 15px;
  position: absolute;
  left: 0;
  top: 1px;
  bottom: 1px
}

.luckysheet-inline-block {
  position: relative;
  display: -moz-inline-box;
  display: inline-block
}

.luckysheet-toolbar-separator {
  line-height: normal;
  list-style: none;
  outline: 0;
  overflow: hidden;
  padding: 0;
  text-decoration: none;
  width: 0;
  height: 20px;
  vertical-align: top;
  border-left: 1px solid #e0e0e0;
  margin: 5px 1px
}

.luckysheet-toolbar-combo-button {
  -webkit-border-radius: 2px;
  -moz-border-radius: 2px;
  border-radius: 2px;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  background: 0;
  border-color: transparent;
  border-style: solid;
  border-width: 1px;
  outline: 0;
  padding: 0;
  color: #333;
  list-style: none;
  font-size: 11px;
  font-weight: 700;
  text-decoration: none;
  cursor: default;
  height: 26px;
  line-height: 26px;
  vertical-align: inherit;
  margin: 0 1px
}

.luckysheet-toolbar-combo-button:hover {
  -webkit-box-shadow: 0 1px 1px rgba(0,0,0,.1);
  -moz-box-shadow: 0 1px 1px rgba(0,0,0,.1);
  box-shadow: 0 1px 1px rgba(0,0,0,.1);
  background-color: #f8f8f8;
  background-image: -webkit-linear-gradient(to bottom,#f8f8f8,#f1f1f1);
  background-image: -moz-linear-gradient(to bottom,#f8f8f8,#f1f1f1);
  background-image: -ms-linear-gradient(to bottom,#f8f8f8,#f1f1f1);
  background-image: -o-linear-gradient(to bottom,#f8f8f8,#f1f1f1);
  background-image: linear-gradient(to bottom,#f8f8f8,#f1f1f1);
  border-color: #c6c6c6!important;
  color: #222;
  border-width: 1px;
  border-color: transparent!important;
  background-color: rgba(0,0,0,.06);
  background-image: none;
  cursor: pointer;
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
  cursor: pointer
}

.luckysheet-toolbar-combo-button:hover .luckysheet-toolbar-combo-button-input {
  border-right-color: rgba(0,0,0,.12)
}

.luckysheet-toolbar-combo-button-open {
  color: #222;
  border-width: 1px;
  border-color: transparent!important;
  background-color: rgba(0,0,0,.12);
  background-image: none;
  cursor: pointer
}

.luckysheet-toolbar-combo-button-open .luckysheet-toolbar-combo-button-input {
  background: 0 0;
  border-right: 1px solid transparent!important
}

.luckysheet-toolbar-combo-button-inner-box,.luckysheet-toolbar-combo-button-outer-box {
  border: 0;
  vertical-align: top;
  margin: 0;
  padding: 0
}

.luckysheet-toolbar-zoom-combobox .luckysheet-toolbar-combo-button-caption {
  width: 36px!important
}

.luckysheet-toolbar-combo-button-caption {
  padding: 0;
  margin: 0 0 0 -3px
}

.luckysheet-toolbar-combo-button-input {
  background: 0 0;
  border: 1px solid transparent!important;
  color: #333;
  font-family: Arial,sans-serif!important;
  font-size: 11px!important;
  font-weight: 700!important;
  height: 20px!important;
  overflow: hidden!important;
  color: rgba(0,0,0,.7);
  height: 22px!important;
  width: 22px
}

.luckysheet-toolbar-combo-button-input:focus {
  box-shadow: inset 0 1px 2px rgba(0,0,0,.3);
  background: #fff;
  outline: 0;
  border: 1px solid #0188fb!important
}

.luckysheet-toolbar-textinput {
  -webkit-border-radius: 1px;
  -moz-border-radius: 1px;
  border-radius: 1px;
  border: 1px solid #d9d9d9;
  border-top: 1px solid silver;
  font-size: 13px;
  height: 25px;
  padding: 1px 0 1px 8px
}

.luckysheet-toolbar-combo-button-dropdown {
  float: right;
  margin: 9px 0 0 0;
  padding: 0 0 0 1px;
  min-width: 7px;
  opacity: .8;
  vertical-align: middle;
  width: 5px;
  height: 7px;
  margin-top: 10px
}

.luckysheet-toolbar-color-menu-button .luckysheet-toolbar-menu-button-caption {
  top: -2px
}

.luckysheet-color-menu-button-indicator {
  position: relative;
  height: 20px
}

.luckysheet-color-menu-button-indicator .text-color-bar {
  position: absolute;
  bottom: 0;
  background-color: #0081f9;
  height: 3px;
  width: 55%;
  left: 30%
}

.luckysheet-toolbar-button-inner-box .luckysheet-icon,.luckysheet-toolbar-menu-button-caption .luckysheet-color-menu-button-indicator .luckysheet-icon,.luckysheet-toolbar-menu-button-caption .luckysheet-icon {
  margin-top: 0
}

.luckysheet-toolbar-menu-button-caption {
  padding: 0;
  margin: 0
}

.luckysheet-toolbar-menu-button-inner-box {
  margin: 0 2px
}

.luckysheet-toolbar-menu-button-dropdown {
  float: right;
  margin: 10px 2px 0 3px;
  padding: 0;
  opacity: .8;
  vertical-align: middle;
  width: 5px;
  height: 7px;
  margin-left: 4px;
  margin-right: 0;
  margin-top: 10px
}

.luckysheet-toolbar-button-split-right .luckysheet-toolbar-menu-button-dropdown {
  padding: 0 3px
}

.luckysheet-toolbar-button-split-left,.luckysheet-toolbar-button-split-left * {
  border-top-right-radius: 0!important;
  border-bottom-right-radius: 0!important;
  margin-right: 0
}

.luckysheet-toolbar-button-split-right,.luckysheet-toolbar-button-split-right * {
  border-top-left-radius: 0!important;
  border-bottom-left-radius: 0!important;
  min-width: 5px!important;
  margin-left: 0
}

#luckysheet-icon-merge-menu {
  margin-right: 1px
}

.luckysheet-toolbar-button,.luckysheet-toolbar-menu-button {
  -webkit-border-radius: 2px;
  -moz-border-radius: 2px;
  border-radius: 2px;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  background: 0;
  border: 1px solid transparent;
  outline: 0;
  padding: 0;
  list-style: none;
  font-size: 11px;
  text-decoration: none;
  vertical-align: middle;
  cursor: default;
  height: 26px;
  line-height: 26px;
  color: #333
}

.luckysheet-toolbar-button-hover,.luckysheet-toolbar-button:hover,.luckysheet-toolbar-menu-button:hover {
  border: 1px solid transparent;
  background-color: rgba(0,0,0,.06);
  background-image: none;
  box-shadow: none;
  cursor: pointer
}

.luckysheet-toolbar-button-split-right.luckysheet-toolbar-menu-button:hover {
  border-left-color: rgba(0,0,0,.12)!important
}

.luckysheet-toolbar-button-split-right-hover {
  border-width: 1px;
  border-color: transparent!important;
  background-color: rgba(0,0,0,.06);
  cursor: pointer;
  box-shadow: none;
  border-left-color: rgba(0,0,0,.12)!important
}

.luckysheet-toolbar-button:active,.luckysheet-toolbar-menu-button:active {
  border: 1px solid transparent;
  background-color: rgba(0,0,0,.12);
  background-image: none;
  box-shadow: none;
  cursor: pointer
}

.luckysheet-toolbar-button-outer-box,.luckysheet-toolbar-menu-button-outer-box {
  border: 0;
  vertical-align: top;
  margin: 0;
  padding: 0
}

.luckysheet-toolbar-button-inner-box,.luckysheet-toolbar-menu-button-inner-box {
  padding: 0 2px;
  padding: 0;
  text-align: center;
  height: 26px;
  min-width: 26px
}

.luckysheet-icon {
  direction: ltr;
  text-align: center;
  overflow: hidden;
  vertical-align: middle;
  height: 26px;
  width: 26px;
  margin: 2px
}

#luckysheet-icon-fmt-other .luckysheet-toolbar-menu-button-caption {
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  width: 55px;
  margin-left: 1px;
  text-align: center
}

#luckysheet-icon-font-family .luckysheet-toolbar-menu-button-caption {
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  width: 55px;
  margin-left: 1px;
  text-align: center
}

#luckysheet-icon-function .luckysheet-toolbar-menu-button-caption {
  margin-right: 5px;
  margin-left: -5px
}

#luckysheet-icon-function .luckysheet-icon {
  margin-right: 0
}

#luckysheet-icon-pivotTable .luckysheet-toolbar-menu-button-caption {
  color: #0188fb
}

#luckysheet-icon-chart .luckysheet-toolbar-menu-button-caption {
  color: #0188fb
}

.luckysheet-rightgclick-menu-sub .sp-container {
  background-color: #fff;
  border: solid 1px #fff
}

#luckysheet-icon-cell-color-menu-menuButton .sp-palette-container,#luckysheet-icon-text-color-menu-menuButton .sp-palette-container {
  margin-bottom: -300px
}

#luckysheet-icon-cell-color-menu-menuButton .sp-palette,#luckysheet-icon-text-color-menu-menuButton .sp-palette {
  margin-top: -10px
}

.luckysheet-wa-calculate {
  height: 28px;
  background: #fff;
  position: relative;
  padding-right: 44px;
  border-bottom: 1px solid #d4d4d4
}

.luckysheet-wa-calculate-help {
  height: 100%;
  width: 99px;
  border-right: 1px solid #d4d4d4
}

.luckysheet-wa-calculate-help-box {
  height: 100%;
  width: 85px;
  position: absolute;
  top: 0;
  left: 0
}

#luckysheet-helpbox {
  left: 0;
  position: absolute;
  right: 0;
  top: 6px;
  resize: none;
  font-family: arial,sans,sans-serif;
  font-size: 14px;
  line-height: 14px;
  background-color: #fff;
  padding: 2px 5px
}

.luckysheet-helpbox-cell-input {
  width: 100%;
  height: 100%;
  margin: 0;
  outline: 0;
  cursor: text;
  -webkit-user-modify: read-write-plaintext-only;
  white-space: nowrap;
  overflow: hidden;
  -webkit-transform: translateZ(0);
  background-color: #fff;
  word-wrap: break-word;
  -webkit-nbsp-mode: space;
  -webkit-line-break: after-white-space
}

.luckysheet-wa-calculate-help-tool {
  position: absolute;
  left: 85px;
  text-align: center;
  height: 100%;
  width: 13px;
  border-left: 1px solid transparent;
  border-right: 1px solid transparent
}

.luckysheet-wa-calculate-help-tool:hover {
  background: #efefef;
  cursor: pointer;
  border-left: 1px solid #e5e5e5;
  border-right: 1px solid #e5e5e5
}

.luckysheet-wa-calculate-size {
  position: absolute;
  height: 3px;
  width: 100%;
  left: 0;
  bottom: 0;
  z-index: 1000
}

.luckysheet-wa-calculate-size:hover {
  background: #5e5e5e;
  cursor: ns-resize
}

#luckysheet-wa-functionbox-cancel {
  left: 104px
}

#luckysheet-wa-functionbox-confirm {
  left: 130px
}

.luckysheet-wa-functionbox {
  position: absolute;
  top: 50%;
  transform: translateY(-50%);
  text-align: center;
  left: 156px;
  color: #d6d6d6
}

.luckysheet-wa-functionbox span {
  vertical-align: middle;
  width: 30px;
  height: 30px
}

.luckysheet-wa-functionbox i {
  font-size: 24px
}

.luckysheet-wa-calculate-active {
  color: #585858;
  cursor: pointer
}

.luckysheet-wa-calculate-active:hover {
  color: #0188fb
}

.luckysheet-grid-container {
  width: 100%;
  position: absolute;
  top: 90px;
  bottom: 0
}

.luckysheet-stat-area {
  position: absolute;
  height: 23px;
  bottom: 0;
  background: #ff00dc;
  width: 100%
}

.luckysheet-sta-c {
  height: 22px;
  background-color: #fff;
  border-top: 1px solid #e1e1e1;
  -moz-user-select: -moz-none;
  -khtml-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none
}

.luckysheet-stat-area:hover .luckysheet-sta-c {
  -moz-user-select: -moz-all;
  -khtml-user-select: initial;
  -webkit-user-select: initial;
  -ms-user-select: initial;
  user-select: initial
}

.luckysheet-sta-c .luckysheet-sta-content {
  height: 22px;
  line-height: 22px;
  text-align: right;
  white-space: nowrap;
  overflow: hidden
}

.luckysheet-sta-c .luckysheet-sta-content span {
  margin-right: 10px
}

.luckysheet-grid-window {
  position: absolute;
  top: 0;
  bottom: 23px;
  left: 0;
  right: 0;
  overflow: hidden;
  background: #0ff
}

.luckysheet-sheet-area {
  position: absolute;
  right: 0;
  bottom: 0;
  left: 0;
  background-color: #fafafc;
  color: #444;
  height: 31px;
  padding: 0 0 0 44px;
  margin: 0;
  -webkit-touch-callout: none;
  cursor: default;
  transition: .3s ease all
}

.luckysheet-sheet-area .luckysheet-sheets-item,.luckysheet-sheet-area>div {
  display: inline-block
}

div.luckysheet-sheets-scroll {
  display: none
}

div.luckysheet-sheets-add:hover,div.luckysheet-sheets-m:hover {
  color: #2a2a2a
}

.docs-sheet-fade {
  position: absolute;
  display: block;
  top: 0;
  width: 6px;
  height: 100%;
  z-index: 1
}

.docs-sheet-fade div {
  background-color: #d7d7d7;
  width: 2px;
  float: right;
  position: relative;
  height: 100%
}

.docs-sheet-fade-left {
  left: 0
}

.docs-sheet-fade-right {
  right: 0
}

.docs-sheet-fade1 {
  opacity: .82
}

.docs-sheet-fade2 {
  opacity: .62
}

.docs-sheet-fade3 {
  opacity: .4
}

.luckysheet-sheet-area div.luckysheet-sheet-container {
  padding: 0 0;
  margin-left: 0;
  position: relative;
  max-width: 50%;
  vertical-align: bottom
}

.luckysheet-sheet-area div.luckysheet-sheet-container div.luckysheet-sheet-container-c {
  padding: 0 0;
  margin-left: 0;
  overflow: hidden;
  white-space: nowrap;
  position: relative;
  max-width: 100%;
  vertical-align: bottom;
  display: inline-block
}

.luckysheet-sheet-container-menu-hide .luckysheet-sheets-item {
  padding-right: 5px!important
}

.luckysheet-sheet-container-menu-hide .luckysheet-sheets-item-menu {
  display: none!important
}

.luckysheet-sheet-area div.luckysheet-sheets-item {
  padding: 2px 6px;
  height: 29px;
  line-height: 29px;
  background-color: #fafafc;
  color: #676464;
  min-width: 30px;
  top: 0;
  position: relative;
  margin-right: -1px;
  cursor: pointer;
  transition: all .1s;
  font-size: 13px;
  padding: 2px 19px 0 5px;
  box-sizing: border-box;
  border-left: 1px solid #e0e0e0;
  border-bottom: 1px solid #e0e0e0;
  border-right: 1px solid #e0e0e0
}

.luckysheet-sheet-area div.luckysheet-sheets-item:last-child {
  margin-right: 1px
}

.luckysheet-sheet-area div.luckysheet-sheets-item:hover {
  background-color: #efefef;
  color: #490500
}

.luckysheet-sheet-area div.luckysheet-sheets-item .luckysheet-sheets-item-menu {
  margin-left: 2px;
  display: inline-block;
  top: -2px;
  position: relative;
  color: #a1a1a1;
  position: absolute;
  height: 100%;
  width: 15px;
  right: 0;
  text-align: center
}

.luckysheet-sheet-area div.luckysheet-sheets-item .luckysheet-sheets-item-menu:hover {
  color: #2a2a2a;
  cursor: pointer
}

.luckysheet-sheet-area div.luckysheet-sheets-item .luckysheet-sheets-item-name {
  padding: 0 3px
}

.luckysheet-sheet-area div.luckysheet-sheets-item .luckysheet-sheets-item-name[contenteditable=true] {
  border: 1px solid #d9d9d9;
  display: inline-block;
  height: 18px;
  line-height: 18px;
  min-width: 8px;
  margin: -4px -1px;
  -moz-user-modify: read-write-plaintext-only;
  -webkit-user-modify: read-write-plaintext-only;
  -moz-user-select: text!important;
  -ms-user-select: text!important;
  -webkit-user-select: text!important
}

.luckysheet-sheet-area div.luckysheet-sheets-item .luckysheet-sheets-item-name[contenteditable=true]:focus {
  -webkit-box-shadow: inset 0 1px 2px rgba(0,0,0,.3);
  -moz-box-shadow: inset 0 1px 2px rgba(0,0,0,.3);
  box-shadow: inset 0 1px 2px rgba(0,0,0,.3);
  border: 1px solid #4d90fe;
  outline: 0
}

.luckysheet-sheet-area div.luckysheet-sheets-item-active {
  height: 29px;
  line-height: 29px;
  background-color: #efefef;
  border-top-color: #fff;
  color: #222;
  cursor: default
}

.luckysheet-sheet-area div.luckysheet-sheets-item-active:hover {
  background-color: #ececec;
  color: #222
}

.luckysheet-grid-window-1 {
  position: absolute;
  top: 0;
  right: 0;
  bottom: 27px;
  left: 0;
  min-width: 200px;
  background-color: #fff!important;
  overflow: hidden;
  -moz-user-select: -moz-none;
  -khtml-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none
}

.luckysheetTableContent {
  position: absolute;
  z-index: 2;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%;
  pointer-events: none;
  -moz-user-select: -moz-none;
  -khtml-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none
}

.luckysheet-grid-window-2 {
  height: 100%;
  width: 100%;
  outline: 0;
  border-collapse: collapse;
  display: table
}

.luckysheet-paneswrapper {
  overflow: hidden;
  height: 1px
}

.luckysheet-left-top {
  width: 44.5px;
  height: 18.5px;
  border: solid 0 #dfdfdf;
  position: relative;
  padding-top: 0;
  border-width: 0 1px 1px 0;
  margin: -1px 0 0 -1px;
  padding-left: 0;
  cursor: pointer
}

.luckysheet-cols-h-c {
  color: #5e5e5e;
  overflow: hidden;
  padding: 0;
  cursor: default;
  height: 19px;
  outline-style: none;
  position: relative;
  -webkit-user-select: none;
  background: #f3f3f2
}

.luckysheet-rows-h {
  position: relative;
  outline-style: none;
  color: #5e5e5e;
  overflow: hidden;
  padding: 0;
  margin-top: -2px;
  padding-top: 2px;
  cursor: default;
  width: 38px;
  background: #f3f3f2
}

.luckysheet-cols-menu-btn {
  color: #5e5e5e;
  cursor: pointer;
  position: absolute;
  z-index: 12;
  border: 1px solid #5e5e5e;
  border-radius: 1px;
  top: 3px;
  margin-left: 0;
  display: none;
  padding: 0 2px;
  font-size: 12px;
  height: 12px;
  opacity: .5
}

.luckysheet-cols-menu-btn:hover {
  opacity: 1
}

.luckysheet-cols-h-hover {
  color: #5e5e5e;
  cursor: default;
  position: absolute;
  z-index: 11;
  border: 0 none;
  bottom: 0;
  height: 100%;
  margin-left: 0;
  display: none;
  background-color: rgba(194,194,194,.4)
}

.luckysheet-cols-h-selected {
  color: #5e5e5e;
  cursor: default;
  position: absolute;
  z-index: 10;
  border-bottom: 1px solid #0188fb;
  bottom: 0;
  height: 100%;
  margin-left: 0;
  display: none;
  transition: all .1s;
  background-color: rgba(76,76,76,.1)
}

.luckysheet-cols-h-cells {
  margin: 0;
  padding: 0;
  border: none 0;
  position: relative;
  height: inherit
}

.luckysheet-cols-h-cells-c {
  color: #5e5e5e;
  cursor: default;
  width: 5000000px;
  height: inherit
}

.luckysheet-cols-h-cells-clip {
  color: #5e5e5e;
  cursor: default;
  margin: 0;
  padding: 0;
  border: none 0;
  position: relative;
  float: left;
  direction: ltr;
  height: inherit;
  width: 2561px;
  color: #5e5e5e;
  border-bottom: solid 1px #bbb;
  position: relative;
  top: -1px
}

.luckysheet-cols-h-cell-nosel {
  position: absolute;
  cursor: pointer;
  border: 0 solid;
  border-color: #dfdfdf;
  display: inline-block;
  min-height: 19px;
  touch-action: manipulation;
  border-right-width: 1px;
  height: inherit
}

.luckysheet-cols-h-cell-sel {
  direction: ltr;
  height: inherit;
  position: absolute;
  cursor: pointer;
  border: 0 solid;
  border-color: #bfbfbf;
  background-color: #e1e1e1;
  display: inline-block;
  min-height: 19px;
  color: #0188fb;
  font-weight: 700;
  touch-action: manipulation;
  border-right-width: 1px
}

.luckysheet-col-flow-h {
  float: left;
  direction: ltr;
  position: relative;
  margin: 0;
  padding: 0;
  border: none 0;
  height: inherit;
  overflow: hidden
}

.luckysheet-col-flow-h-sheet {
  width: inherit;
  height: inherit;
  position: relative;
  float: left;
  direction: ltr
}

body:not(.ewa-ipad) .luckysheet-cols-h-cell-nosel:hover,body:not(.ewa-ipad) .luckysheet-cols-h-cell-sel:hover,body:not(.ewa-ipad) .luckysheet-rows-h-cell-nosel:hover,body:not(.ewa-ipad) .luckysheet-rows-h-cell-sel:hover {
  background-color: #fcc3c3
}

.luckysheet-cols-h-cell-txt {
  cursor: pointer;
  height: inherit;
  position: relative;
  text-align: center;
  overflow: hidden;
  touch-action: manipulation;
  font-size: 14px;
  padding-top: 2px
}

.luckysheet-rows-h {
  position: relative;
  outline-style: none;
  color: #5e5e5e;
  overflow: hidden;
  padding: 0;
  margin-top: -2px;
  padding-top: 2px;
  cursor: default;
  width: 45px
}

.luckysheet-rows-h-hover {
  position: absolute;
  z-index: 11;
  border: 0 none;
  right: 0;
  width: 100%;
  margin-top: 2px;
  display: none;
  background-color: rgba(194,194,194,.4)
}

.luckysheet-rows-h-selected {
  position: absolute;
  z-index: 10;
  border-right: 1px solid #0188fb;
  right: 0;
  width: 100%;
  margin-top: 2px;
  display: none;
  transition: all .1s;
  background-color: rgba(76,76,76,.1)
}

.luckysheet-rows-h-cells {
  margin: 0;
  padding: 0;
  border: none 0;
  position: relative;
  width: 100%
}

.luckysheet-rows-h-cells-c {
  margin: 0;
  padding: 0;
  border: none 0;
  position: relative;
  float: left;
  direction: ltr;
  width: 100%
}

.luckysheet-rows-h-cells-clip {
  cursor: default;
  color: #5e5e5e;
  direction: ltr;
  border-right: solid 1px #bbb;
  width: inherit;
  height: inherit;
  position: relative;
  left: -1px;
  height: inherit
}

.luckysheet-rows-h-cell-nosel {
  direction: ltr;
  width: 100%;
  position: absolute;
  cursor: pointer;
  border: 0 solid;
  border-color: #dfdfdf;
  border-bottom-width: 1px;
  touch-action: manipulation
}

.luckysheet-rows-h-cell-sel {
  direction: ltr;
  width: 100%;
  position: absolute;
  cursor: pointer;
  border: 0 solid;
  border-color: #bfbfbf;
  background-color: #e1e1e1;
  border-bottom-width: 1px;
  color: #0188fb;
  font-weight: 700;
  touch-action: manipulation
}

.luckysheet-rows-h-cell-txt {
  width: 100%;
  position: absolute;
  bottom: 0;
  text-align: center;
  padding-bottom: 1px;
  max-height: 100%;
  overflow: hidden;
  font-size: 14px
}

.luckysheet-cell-loading {
  width: 100%;
  height: 100%;
  background-color: rgba(255,255,255,.3);
  position: absolute;
  overflow: hidden;
  outline-style: none;
  cursor: not-allowed;
  font-size: 28px;
  z-index: 2;
  display: none
}

.luckysheet-cell-loading-inner {
  position: relative;
  top: 40%;
  width: 100%;
  margin: 0 auto;
  text-align: center
}

.luckysheet-cell-loading-inner span {
  margin-left: 10px
}

.luckysheet-cell-main {
  background-color: #fff;
  width: 15px;
  height: 15px;
  background-color: #f3f3f2;
  border-collapse: collapse;
  position: relative;
  overflow: hidden;
  outline-style: none;
  cursor: default
}

.luckysheet-menu,.luckysheet-scrollbars {
  scrollbar-base-color:#fff;scrollbar-track-color:#e7e7e7;scrollbar-darkshadow-color: #fff;
  scrollbar-3dlight-color: #fff;
  scrollbar-arrow-color:#757778;scrollbar-shadow-color:#bec1c4;scrollbar-highlight-color:#bec1c4;-ms-scroll-chaining: none;
  overflow: auto
}

.luckysheet-scrollbar-ltr {
  position: absolute;
  overflow: hidden;
  z-index: 1003
}

.luckysheet-scrollbar-ltr div {
  height: 1px;
  width: 1px
}

.luckysheet-scrollbar-ltr::-webkit-scrollbar-button {
  height: 0;
  width: 0
}

.luckysheet-scrollbar-ltr::-webkit-scrollbar-button:start {
  display: none
}

.luckysheet-scrollbar-ltr::-webkit-scrollbar-button:end {
  display: block
}

.luckysheet-scrollbar-ltr::-webkit-scrollbar-button {
  border: 1px solid #d9d9d9
}

.luckysheet-scrollbar-ltr::-webkit-scrollbar-button:horizontal {
  border-width: 1px 0 0 0
}

.luckysheet-scrollbar-ltr::-webkit-scrollbar-button:vertical {
  border-width: 0 0 0 1px
}

.luckysheet-scrollbar-ltr::-webkit-scrollbar-button:vertical {
  border-width: 0 1px 0 0
}

.luckysheet-scrollbar-ltr::-webkit-scrollbar-button:horizontal:increment {
  background: no-repeat url(waffle_sprite.png) -663px -13px;
  width: 15px;
  padding-left: 1px;
  background-clip: border-box;
  border: 1px solid #d9d9d9;
  border-width: 1px 0 0 0;
  box-shadow: none;
  background-color: #f8f8f8;
  border-bottom: 1px solid #d9d9d9
}

.luckysheet-scrollbar-ltr::-webkit-scrollbar-button:horizontal:increment:hover {
  background: no-repeat url(waffle_sprite.png) -395px -62px
}

.luckysheet-scrollbar-ltr::-webkit-scrollbar-button:horizontal:increment:active {
  background: no-repeat url(waffle_sprite.png) -679px -13px
}

.luckysheet-scrollbar-ltr::-webkit-scrollbar-button:horizontal:decrement {
  border-left: 1px solid #d9d9d9;
  border-right: 1px solid #d9d9d9;
  background: no-repeat url(waffle_sprite.png) -283px -62px;
  width: 17px;
  border-bottom: 1px solid #d9d9d9
}

.luckysheet-scrollbar-ltr::-webkit-scrollbar-button:horizontal:hover {
  background: no-repeat url(waffle_sprite.png) -145px -70px
}

.luckysheet-scrollbar-ltr::-webkit-scrollbar-button:horizontal:active {
  background: no-repeat url(waffle_sprite.png) -552px 0
}

.luckysheet-scrollbar-ltr::-webkit-scrollbar-button:vertical:increment {
  padding-top: 1px;
  background: no-repeat url(waffle_sprite.png) -531px -24px;
  border-left: 1px solid #d9d9d9;
  height: 15px
}

.luckysheet-scrollbar-ltr::-webkit-scrollbar-button:vertical:increment:hover {
  background: no-repeat url(waffle_sprite.png) -570px -42px
}

.luckysheet-scrollbar-ltr::-webkit-scrollbar-button:vertical:increment:active {
  background: no-repeat url(waffle_sprite.png) -83px -46px
}

.luckysheet-scrollbar-ltr::-webkit-scrollbar-button:vertical:decrement {
  border-top: 1px solid #d9d9d9;
  border-bottom: 1px solid #d9d9d9;
  border-left: 1px solid #d9d9d9;
  background: no-repeat url(waffle_sprite.png) -631px -27px;
  height: 17px
}

.luckysheet-scrollbar-ltr::-webkit-scrollbar-button:vertical:decrement:hover {
  background: no-repeat url(waffle_sprite.png) -180px -58px
}

.luckysheet-scrollbar-ltr::-webkit-scrollbar-button:vertical:decrement:active {
  background: no-repeat url(waffle_sprite.png) -776px -28px
}

.luckysheet-scrollbar-x {
  bottom: 0;
  left: 44px;
  overflow-x: scroll
}

.luckysheet-scrollbar-y {
  right: 0;
  top: 0;
  overflow-y: scroll
}

.luckysheet-cell-flow {
  margin: 0;
  padding: 0;
  border: none 0;
  position: relative;
  touch-action: manipulation;
  overflow: hidden
}

.luckysheet-cell-flow-clip {
  border-collapse: collapse;
  cursor: default;
  width: 5000000px;
  touch-action: manipulation;
  overflow: hidden
}

.luckysheet-cell-flow-col {
  margin: 0;
  padding: 0;
  border: none 0;
  position: relative;
  touch-action: manipulation;
  overflow: hidden;
  float: left;
  direction: ltr
}

.luckysheet-cell-sheettable {
  position: relative;
  text-align: left;
  font-size: 11pt;
  color: #000;
  text-decoration: none
}

.luckysheet-bottom-controll-row {
  position: absolute;
  height: 30px;
  bottom: 38px;
  left: 0;
  z-index: 1000
}

#luckysheet-bottom-add-row {
  padding: 5px 20px;
  margin-right: 5px;
  margin-top: -2px
}

#luckysheet-bottom-add-row-input {
  width: 40px;
  min-width: 40px
}

#luckysheet-bottom-return-top {
  padding: 5px 6px;
  margin-left: 10px;
  margin-top: -2px
}

.luckysheet-cell-flow-column {
  position: absolute;
  height: inherit;
  width: inherit;
  top: 0;
  left: 0;
  z-index: 1;
  touch-action: manipulation
}

.luckysheet-cell-flow-column-line {
  position: absolute;
  border-right: 1px solid #d4d4d4;
  height: inherit
}

.luckysheet-cell-flow-row {
  text-align: left;
  position: absolute;
  height: inherit;
  width: inherit;
  top: 0;
  left: 0;
  z-index: 1;
  touch-action: manipulation
}

.luckysheet-cell-flow-row-line {
  position: absolute;
  border-bottom: 1px solid #d4d4d4;
  width: inherit
}

.luckysheet-cell-selected-focus {
  position: absolute;
  pointer-events: none;
  z-index: 14;
  margin: 0;
  background: rgba(0,80,208,.15);
  display: none
}

.luckysheet-selection-copy {
  position: absolute;
  pointer-events: none;
  z-index: 18;
  border: none;
  margin: 0;
  display: none
}

.luckysheet-selection-copy .luckysheet-copy {
  position: absolute;
  z-index: 18;
  background-color: transparent
}

.luckysheet-selection-copy-top {
  left: 0;
  right: 0;
  height: 2px;
  top: 0;
  background-position: bottom;
  background-image: url(EwaAntH.gif)
}

.luckysheet-selection-copy-right {
  top: 0;
  bottom: 0;
  width: 2px;
  right: 0;
  background-image: url(EwaAntV.gif)
}

.luckysheet-selection-copy-bottom {
  left: 0;
  right: 0;
  height: 2px;
  bottom: 0;
  background-image: url(EwaAntH.gif)
}

.luckysheet-selection-copy-left {
  top: 0;
  bottom: 0;
  width: 2px;
  left: 0;
  background-position: right;
  background-image: url(EwaAntV.gif)
}

.luckysheet-selection-copy-hc {
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  border: 2px dashed #12a5ff;
  z-index: 8
}

.luckysheet-selection-highlight {
  position: absolute;
  z-index: 14;
  border: none;
  margin: 0;
  display: none
}

.luckysheet-formula-functionrange-highlight .luckysheet-copy {
  background-image: none;
  background: #0188fb;
  position: absolute;
  z-index: 18;
  cursor: move;
  opacity: .9
}

.luckysheet-formula-functionrange-highlight .luckysheet-selection-copy-top {
  top: -2px;
  border-top: 2px solid #fff;
  border-bottom: 2px solid #fff
}

.luckysheet-formula-functionrange-highlight .luckysheet-selection-copy-right {
  right: -2px;
  border-left: 2px solid #fff;
  border-right: 2px solid #fff
}

.luckysheet-formula-functionrange-highlight .luckysheet-selection-copy-bottom {
  bottom: -2px;
  border-top: 2px solid #fff;
  border-bottom: 2px solid #fff
}

.luckysheet-formula-functionrange-highlight .luckysheet-selection-copy-left {
  left: -2px;
  border-left: 2px solid #fff;
  border-right: 2px solid #fff
}

.luckysheet-formula-functionrange-highlight .luckysheet-selection-copy-hc {
  border: 2px solid #5e5e5e;
  opacity: .03;
  z-index: initial
}

.luckysheet-selection-highlight-topleft {
  left: -3px;
  top: -3px;
  cursor: se-resize
}

.luckysheet-selection-highlight-topright {
  right: -3px;
  top: -3px;
  cursor: ne-resize
}

.luckysheet-selection-highlight-bottomleft {
  left: -3px;
  bottom: -3px;
  cursor: ne-resize
}

.luckysheet-selection-highlight-bottomright {
  right: -3px;
  bottom: -3px;
  cursor: se-resize
}

.luckysheet-formula-functionrange-highlight .luckysheet-highlight {
  position: absolute;
  z-index: 19;
  border: 1px solid #fff;
  background: #0188fb;
  width: 6px;
  height: 6px
}

.luckysheet-cell-selected-extend {
  position: absolute;
  pointer-events: none;
  z-index: 16;
  border: 1px dashed #0188fb;
  margin: -1px 0 0 -1px;
  display: none
}

.luckysheet-cell-selected-move {
  position: absolute;
  pointer-events: none;
  z-index: 16;
  border: 2px solid #0188fb;
  margin: -1px 0 0 -1px;
  display: none
}

.luckysheet-cell-selected {
  position: absolute;
  pointer-events: none;
  z-index: 15;
  border: 1px solid #0188fb;
  margin: -1px 0 0 -1px;
  background: rgba(1,136,251,.15);
  display: none
}

.luckysheet-cs-inner-border {
  pointer-events: none;
  border: 1px solid #fff;
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0
}

.luckysheet-cs-fillhandle {
  position: absolute;
  width: 6px;
  height: 6px;
  bottom: -5px;
  cursor: crosshair;
  background-color: #0188fb;
  border: solid 1px #fff;
  z-index: 16;
  pointer-events: auto;
  right: -5px
}

.luckysheet-cs-draghandle {
  position: absolute;
  cursor: move;
  background-color: #fff;
  opacity: .01;
  z-index: 15;
  pointer-events: auto;
  border: 2px solid #fff
}

.luckysheet-cs-draghandle-top {
  top: -4px;
  left: -2px;
  right: -2px;
  height: 2px
}

.luckysheet-cs-draghandle-bottom {
  right: 0;
  left: -2px;
  bottom: -4px;
  height: 2px
}

.luckysheet-cs-draghandle-left {
  top: 0;
  left: -4px;
  bottom: 0;
  width: 2px
}

.luckysheet-cs-draghandle-right {
  top: 0;
  right: -4px;
  bottom: 0;
  width: 2px
}

.luckysheet-cs-touchhandle {
  display: none;
  position: absolute;
  width: 16px;
  height: 16px;
  padding: 5px;
  z-index: 100;
  pointer-events: auto;
  touch-action: auto
}

.luckysheet-cs-touchhandle:before {
  content: '';
  display: block;
  width: 16px;
  height: 16px;
  border: .5px solid rgba(0,0,0,.15);
  background-color: #fff;
  box-sizing: border-box;
  border-radius: 50%
}

.luckysheet-cs-touchhandle-lt {
  left: -13px;
  top: -13px
}

.luckysheet-cs-touchhandle-lb {
  left: -13px;
  bottom: -13px
}

.luckysheet-cs-touchhandle-rt {
  right: -13px;
  top: -13px
}

.luckysheet-cs-touchhandle-rb {
  right: -13px;
  bottom: -13px
}

.luckysheet-cs-touchhandle .luckysheet-cs-touchhandle-btn {
  position: absolute;
  width: 10px;
  height: 10px;
  left: 8px;
  top: 8px;
  background-color: #018ffb;
  background-position: center;
  box-sizing: border-box;
  border-radius: 50%;
  z-index: 11
}

#luckysheet-dynamicArray-hightShow {
  position: absolute;
  pointer-events: none;
  z-index: 15;
  border: 1px solid #00f;
  margin: -1px 0 0 -1px;
  display: none
}

.luckysheet-scrollbars::-webkit-scrollbar-track {
  background-color: #fff;
  border: 1px solid #d9d9d9
}

.luckysheet-scrollbar-x::-webkit-scrollbar-track {
  border-left: 1px solid #d9d9d9;
  border-right: none
}

.luckysheet-scrollbar-y::-webkit-scrollbar-track {
  border-top: none;
  border-bottom: none
}

.luckysheet-scrollbars::-webkit-scrollbar {
  width: 12px;
  height: 12px;
  background-color: #fff
}

.luckysheet-scrollbars::-webkit-scrollbar-thumb {
  background-color: rgba(0,0,0,.2);
  background-clip: padding-box;
  border: solid transparent;
  border-radius: 12px;
  border-width: 2px 1px 1px 2px;
  box-shadow: inset 1px 1px 0 rgba(0,0,0,.1),inset 0 -1px 0 rgba(0,0,0,.07)
}

.luckysheet-scrollbars::-webkit-scrollbar-thumb:hover {
  background-color: #969696;
  border: 1px solid #a0a0a0;
  border-radius: 12px
}

.luckysheet-grdusedrange {
  position: absolute;
  visibility: hidden;
  width: 1px;
  height: 1px
}

.luckysheet-grdblkflowpush {
  margin: 0;
  padding: 0;
  border: none 0;
  width: 1px
}

.luckysheet-grdblkpush {
  margin: 0;
  padding: 0;
  border: none 0;
  height: 1px;
  float: left;
  direction: ltr
}

.luckysheet-cell-flow-data {
  position: absolute;
  height: inherit;
  width: inherit;
  top: 0;
  left: 0;
  z-index: 1
}

.luckysheet-cell-flow-data-row {
  position: absolute;
  width: inherit
}

.luckysheet-cell-flow-data-cell {
  position: absolute;
  height: inherit
}

.luckysheet-cell-flow-data-value {
  position: absolute!important;
  bottom: 0;
  letter-spacing: -.02em;
  white-space: nowrap;
  padding-left: 2px;
  overflow: hidden
}

.luckysheet canvas {
  position: absolute
}

.luckysheetcolumeHeader {
  margin-left: -1px
}

.luckysheetrowHeader {
  margin-top: 1px
}

.luckysheetsheettable {
  margin-left: -1px;
  margin-top: -1px
}

.luckysheet-cols-menu {
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
  -webkit-box-shadow: 0 2px 4px rgba(0,0,0,.2);
  -moz-box-shadow: 0 2px 4px rgba(0,0,0,.2);
  box-shadow: 0 2px 4px rgba(0,0,0,.2);
  -webkit-transition: opacity 218ms;
  -moz-transition: opacity 218ms;
  -o-transition: opacity 218ms;
  transition: opacity 218ms;
  background: #fff;
  border: 1px solid #ccc;
  border: 1px solid rgba(0,0,0,.2);
  cursor: default;
  font-size: 13px;
  margin: 0;
  outline: 0;
  padding: 6px 0;
  position: absolute;
  z-index: 1004;
  box-sizing: border-box;
  user-select: none;
  display: none
}

.luckysheet-cols-menu .luckysheet-cols-menuitem {
  position: relative;
  color: #333;
  cursor: pointer;
  list-style: none;
  margin: 0;
  padding: 1px 6em 1px 20px;
  white-space: nowrap;
  padding-left: 8px;
  vertical-align: middle;
  padding-right: 24px;
  user-select: none
}

.luckysheet-cols-menu .luckysheet-cols-menuitem-hover,.luckysheet-cols-menu .luckysheet-cols-menuitem:hover {
  background: #efefef
}

.luckysheet-cols-menu .luckysheet-cols-menuitem .luckysheet-cols-menuitem-content {
  position: relative;
  color: #333;
  cursor: pointer;
  list-style: none;
  margin: 0;
  padding: 6px 7em 6px 30px;
  white-space: nowrap;
  user-select: none
}

.luckysheet-rightgclick-menu .luckysheet-cols-menuitem .luckysheet-cols-menuitem-content {
  position: relative;
  color: #333;
  cursor: pointer;
  list-style: none;
  margin: 0;
  padding: 6px 15px 6px 20px;
  white-space: nowrap;
  user-select: none
}

#luckysheet-cols-menu .luckysheet-cols-menuitem,#luckysheet-pivotTable-config-option .luckysheet-cols-menuitem,.luckysheet-filter-menu .luckysheet-cols-menuitem {
  padding-right: 10px;
  padding-left: 12px
}

#luckysheet-pivotTable-config-option-sumtype .luckysheet-cols-menuitem {
  padding-right: 15px;
  padding-left: 12px;
  padding-top: 1px;
  padding-bottom: 1px
}

#luckysheet-cols-menu .luckysheet-cols-menuitem-content,.luckysheet-filter-menu .luckysheet-cols-menuitem .luckysheet-cols-menuitem-content {
  padding-right: 10px;
  padding-left: 12px
}

#luckysheet-sheet-list .luckysheet-cols-menuitem .luckysheet-cols-menuitem-content {
  padding-right: 0;
  max-width: 430px;
  min-width: 100px;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap
}

.luckysheet-filter-menu div.luckysheet-cols-menuitem {
  padding-top: 0;
  padding-bottom: 0
}

.luckysheet-filter-submenu div.luckysheet-cols-menuitem {
  padding-top: 1px;
  padding-bottom: 1px
}

.luckysheet-filter-menu .luckysheet-filter-byvalue .luckysheet-cols-menuitem,.luckysheet-filter-menu .luckysheet-pivotTableFilter-byvalue .luckysheet-cols-menuitem {
  padding-top: 2px;
  padding-bottom: 0;
  cursor: default
}

.luckysheet-filter-menu .luckysheet-filter-byvalue .luckysheet-cols-menuitem-content,.luckysheet-filter-menu .luckysheet-pivotTableFilter-byvalue .luckysheet-cols-menuitem-content {
  padding-top: 2px;
  padding-bottom: 0;
  cursor: default
}

.luckysheet-filter-menu .luckysheet-filter-byvalue .luckysheet-cols-menuitem-content input,.luckysheet-filter-menu .luckysheet-pivotTableFilter-byvalue .luckysheet-cols-menuitem-content input {
  height: 24px;
  width: 191px;
  padding-right: 25px;
  padding-left: 3px;
  -webkit-border-radius: 1px;
  -moz-border-radius: 1px;
  border-radius: 1px;
  border: 1px solid #d9d9d9;
  border-top: 1px solid silver;
  font-size: 13px
}

.luckysheet-filter-menu .luckysheet-filter-byvalue .luckysheet-cols-menuitem-content input:focus,.luckysheet-filter-menu .luckysheet-pivotTableFilter-byvalue .luckysheet-cols-menuitem-content input:focus {
  -webkit-box-shadow: inset 0 1px 2px rgba(0,0,0,.3);
  -moz-box-shadow: inset 0 1px 2px rgba(0,0,0,.3);
  box-shadow: inset 0 1px 2px rgba(0,0,0,.3);
  border: 1px solid #4d90fe;
  outline: 0
}

.luckysheet-filter-menu .luckysheet-filter-byvalue .luckysheet-cols-menuitem-content .luckysheet-filter-byvalue-input-icon,.luckysheet-filter-menu .luckysheet-pivotTableFilter-byvalue .luckysheet-cols-menuitem-content .luckysheet-pivotTableFilter-byvalue-input-icon {
  position: absolute;
  right: 17px;
  top: 7px
}

.luckysheet-filter-menu .luckysheet-filter-byvalue .luckysheet-cols-menuitem:hover,.luckysheet-filter-menu .luckysheet-pivotTableFilter-byvalue .luckysheet-cols-menuitem:hover {
  background: #fff
}

.luckysheet-filter-menu .luckysheet-cols-menuitem:last-child:hover {
  background: #fff
}

.luckysheet-filter-menu .luckysheet-cols-menuitem:last-child,.luckysheet-filter-menu .luckysheet-cols-menuitem:last-child .luckysheet-cols-menuitem-content {
  cursor: default
}

#luckysheet-filter-byvalue-select,#luckysheet-pivotTableFilter-byvalue-select {
  min-height: 100px;
  width: 200px
}

.luckysheet-filter-menu .luckysheet-mousedown-filter-byvalue-btn span,.luckysheet-filter-menu .luckysheet-mousedown-pivotTableFilter-byvalue-btn span {
  color: #00f;
  cursor: pointer;
  text-decoration: underline
}

.luckysheet-filter-menu .luckysheet-mousedown-filter-byvalue-btn div,.luckysheet-filter-menu .luckysheet-mousedown-pivotTableFilter-byvalue-btn div {
  position: absolute;
  right: 14px;
  top: 0;
  font-size: 18px
}

.luckysheet-filter-menu .luckysheet-filter-bycondition .luckysheet-filter-selected-input,.luckysheet-filter-menu .luckysheet-pivotTableFilter-bycondition .luckysheet-pivotTableFilter-selected-input {
  padding-left: 8px;
  padding-right: 8px;
  margin-top: 3px;
  display: none
}

.luckysheet-filter-menu .luckysheet-filter-bycondition .luckysheet-filter-selected-input input,.luckysheet-filter-menu .luckysheet-pivotTableFilter-bycondition .luckysheet-pivotTableFilter-selected-input input {
  height: 24px;
  width: 100%;
  padding-right: 3px;
  padding-left: 3px;
  margin-left: -3px;
  -webkit-border-radius: 1px;
  -moz-border-radius: 1px;
  border-radius: 1px;
  border: 1px solid #d9d9d9;
  border-top: 1px solid silver;
  font-size: 13px
}

.luckysheet-filter-menu .luckysheet-filter-bycondition .luckysheet-filter-selected-input2 input,.luckysheet-filter-menu .luckysheet-pivotTableFilter-bycondition .luckysheet-pivotTableFilter-selected-input2 input {
  height: 24px;
  width: 92px;
  padding-right: 3px;
  padding-left: 3px;
  margin-left: -3px;
  -webkit-border-radius: 1px;
  -moz-border-radius: 1px;
  border-radius: 1px;
  border: 1px solid #d9d9d9;
  border-top: 1px solid silver;
  font-size: 13px
}

.luckysheet-filter-menu .luckysheet-filter-bycondition .luckysheet-filter-selected-input2 span,.luckysheet-filter-menu .luckysheet-pivotTableFilter-bycondition .luckysheet-pivotTableFilter-selected-input2 span {
  margin-left: 2px;
  margin-right: 5px
}

.luckysheet-menuseparator {
  border-top: 1px solid #ebebeb;
  margin-top: 6px;
  margin-bottom: 6px
}

.luckysheet-submenu-arrow {
  -webkit-transition: all 218ms;
  -moz-transition: all 218ms;
  -o-transition: all 218ms;
  transition: all 218ms;
  font-size: 12px;
  left: auto;
  right: -15px;
  padding-top: 1px;
  padding-right: 0;
  position: absolute;
  text-align: right;
  opacity: .5;
  color: #000;
  user-select: none;
  font-family: Arial;
  line-height: 100%
}

#luckysheet-pivotTable-config-option-sumtype .luckysheet-submenu-arrow {
  right: -5px;
  font-size: 16px;
  padding-top: 0;
  color: #00f
}

#luckysheet-filter-byvalue-select table,#luckysheet-pivotTableFilter-byvalue-select table {
  table-layout: fixed
}

#luckysheet-filter-byvalue-select tr td,#luckysheet-pivotTableFilter-byvalue-select tr td {
  padding: 2px 3px
}

#luckysheet-filter-byvalue-select tr:hover td,#luckysheet-pivotTableFilter-byvalue-select tr:hover td {
  background: #e1e1e1
}

.luckysheet-cols-menu .cf:after,.luckysheet-cols-menu .cf:before {
  content: "";
  display: table
}

.luckysheet-cols-menu .cf:after {
  clear: both
}

#luckysheet-filter-byvalue-select .yearBox .monthList,#luckysheet-pivotTableFilter-byvalue-select .yearBox .monthList {
  padding-left: 20px
}

#luckysheet-filter-byvalue-select .yearBox .dayList,#luckysheet-pivotTableFilter-byvalue-select .yearBox .dayList {
  padding-left: 20px
}

#luckysheet-filter-byvalue-select .yearBox .fa-caret-right,#luckysheet-pivotTableFilter-byvalue-select .yearBox .fa-caret-right {
  padding: 0 2px;
  float: left;
  margin-top: 3px;
  cursor: pointer
}

#luckysheet-filter-byvalue-select .count,#luckysheet-pivotTableFilter-byvalue-select .count {
  color: gray;
  margin-left: 5px
}

#luckysheet-filter-byvalue-select input[type=checkbox],#luckysheet-pivotTableFilter-byvalue-select input[type=checkbox] {
  width: auto;
  height: auto;
  float: left
}

#luckysheet-filter-orderby-color-submenu {
  font-size: 12px
}

#luckysheet-filter-orderby-color-submenu .title {
  padding: 10px;
  font-weight: 600;
  color: #333;
  background-color: #f4f4f4;
  text-align: center
}

#luckysheet-filter-orderby-color-submenu .item {
  padding: 5px 40px 5px 20px;
  cursor: pointer;
  position: relative
}

#luckysheet-filter-orderby-color-submenu .item:hover {
  background-color: #d3d3d3
}

#luckysheet-filter-orderby-color-submenu .item label {
  display: block;
  width: 70px;
  height: 20px;
  border: 1px solid #d1d1d1
}

#luckysheet-filter-orderby-color-submenu .item input[type=checkbox] {
  position: absolute;
  right: 10px;
  top: 6px
}

#luckysheet-copy-content {
  position: fixed;
  height: 0;
  width: 0;
  left: -100px;
  padding-left: 999999px
}

.btn {
  display: inline-block;
  margin-bottom: 0;
  font-weight: 400;
  text-align: center;
  vertical-align: middle;
  -ms-touch-action: manipulation;
  touch-action: manipulation;
  cursor: pointer;
  background-image: none;
  border: 1px solid transparent;
  white-space: nowrap;
  padding: 4px 8px;
  font-size: 14px;
  line-height: 1.42857143;
  border-radius: 2px;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none
}

.btn.active.focus,.btn.active:focus,.btn.focus,.btn:active.focus,.btn:active:focus,.btn:focus {
  outline: thin dotted;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px
}

.btn.focus,.btn:focus,.btn:hover {
  color: #333;
  text-decoration: none
}

.btn.active,.btn:active {
  outline: 0;
  background-image: none;
  -webkit-box-shadow: inset 0 3px 5px rgba(0,0,0,.125);
  box-shadow: inset 0 3px 5px rgba(0,0,0,.125)
}

.btn.disabled,.btn[disabled],fieldset[disabled] .btn {
  cursor: not-allowed;
  opacity: .65;
  -webkit-box-shadow: none;
  box-shadow: none
}

a.btn.disabled,fieldset[disabled] a.btn {
  pointer-events: none
}

.btn-default {
  color: #333;
  background-color: #fff;
  border-color: #ccc
}

.btn-default.focus,.btn-default:focus {
  color: #333;
  background-color: #e6e6e6;
  border-color: #8c8c8c
}

.btn-default:hover {
  color: #333;
  background-color: #e6e6e6;
  border-color: #adadad
}

.btn-default.active,.btn-default:active,.open>.dropdown-toggle.btn-default {
  color: #333;
  background-color: #e6e6e6;
  border-color: #adadad
}

.btn-default.active.focus,.btn-default.active:focus,.btn-default.active:hover,.btn-default:active.focus,.btn-default:active:focus,.btn-default:active:hover,.open>.dropdown-toggle.btn-default.focus,.open>.dropdown-toggle.btn-default:focus,.open>.dropdown-toggle.btn-default:hover {
  color: #333;
  background-color: #d4d4d4;
  border-color: #8c8c8c
}

.btn-default.active,.btn-default:active,.open>.dropdown-toggle.btn-default {
  background-image: none
}

.btn-default.disabled.focus,.btn-default.disabled:focus,.btn-default.disabled:hover,.btn-default[disabled].focus,.btn-default[disabled]:focus,.btn-default[disabled]:hover,fieldset[disabled] .btn-default.focus,fieldset[disabled] .btn-default:focus,fieldset[disabled] .btn-default:hover {
  background-color: #fff;
  border-color: #ccc
}

.btn-default .badge {
  color: #fff;
  background-color: #333
}

.btn-primary {
  color: #fff;
  background-color: #2d7ff9;
  border-color: transparent
}

.btn-primary.focus,.btn-primary:focus {
  color: #fff;
  background-color: #286090;
  border-color: transparent
}

.btn-primary:hover {
  color: #fff;
  background-color: #5391ff;
  border-color: transparent
}

.btn-primary.active,.btn-primary:active,.open>.dropdown-toggle.btn-primary {
  color: #fff;
  background-color: #5391ff
}

.btn-primary.active.focus,.btn-primary.active:focus,.btn-primary.active:hover,.btn-primary:active.focus,.btn-primary:active:focus,.btn-primary:active:hover,.open>.dropdown-toggle.btn-primary.focus,.open>.dropdown-toggle.btn-primary:focus,.open>.dropdown-toggle.btn-primary:hover {
  color: #fff;
  background-color: #204d74;
  border-color: transparent
}

.btn-primary.active,.btn-primary:active,.open>.dropdown-toggle.btn-primary {
  background-image: none
}

.btn-primary.disabled,.btn-primary.disabled.active,.btn-primary.disabled.focus,.btn-primary.disabled:active,.btn-primary.disabled:focus,.btn-primary.disabled:hover,.btn-primary[disabled],.btn-primary[disabled].active,.btn-primary[disabled].focus,.btn-primary[disabled]:active,.btn-primary[disabled]:focus,.btn-primary[disabled]:hover,fieldset[disabled] .btn-primary,fieldset[disabled] .btn-primary.active,fieldset[disabled] .btn-primary.focus,fieldset[disabled] .btn-primary:active,fieldset[disabled] .btn-primary:focus,fieldset[disabled] .btn-primary:hover {
  background-color: #337ab7;
  border-color: transparent
}

.btn-primary .badge {
  color: #337ab7;
  background-color: #fff
}

.btn-primary,.label-default,.list-group-item.active,.list-group-item.active:focus,.list-group-item.active:hover {
  background: #0188fb;
  border-color: transparent
}

.btn-primary:focus,.btn-primary:hover {
  background: #5391ff;
  border-color: transparent
}

.btn-danger {
  color: #fff;
  background-color: #d9534f;
  border-color: #d43f3a
}

.btn-danger.focus,.btn-danger:focus {
  color: #fff;
  background-color: #c9302c;
  border-color: #761c19
}

.btn-danger:hover {
  color: #fff;
  background-color: #c9302c;
  border-color: #ac2925
}

.btn-danger.active,.btn-danger:active,.open>.dropdown-toggle.btn-danger {
  color: #fff;
  background-color: #c9302c;
  border-color: #ac2925
}

.btn-danger.active.focus,.btn-danger.active:focus,.btn-danger.active:hover,.btn-danger:active.focus,.btn-danger:active:focus,.btn-danger:active:hover,.open>.dropdown-toggle.btn-danger.focus,.open>.dropdown-toggle.btn-danger:focus,.open>.dropdown-toggle.btn-danger:hover {
  color: #fff;
  background-color: #ac2925;
  border-color: #761c19
}

.btn-danger.active,.btn-danger:active,.open>.dropdown-toggle.btn-danger {
  background-image: none
}

.btn-danger.disabled.focus,.btn-danger.disabled:focus,.btn-danger.disabled:hover,.btn-danger[disabled].focus,.btn-danger[disabled]:focus,.btn-danger[disabled]:hover,fieldset[disabled] .btn-danger.focus,fieldset[disabled] .btn-danger:focus,fieldset[disabled] .btn-danger:hover {
  background-color: #d9534f;
  border-color: #d43f3a
}

.btn-danger .badge {
  color: #d9534f;
  background-color: #fff
}

.luckysheet-change-size-line,.luckysheet-cols-change-size,.luckysheet-rows-change-size {
  position: absolute;
  z-index: 12
}

.luckysheet-cols-change-size {
  width: 5px;
  height: 100%;
  background: #0188fb;
  cursor: ew-resize;
  opacity: 0
}

.luckysheet-rows-change-size {
  width: 100%;
  height: 5px;
  background: #0188fb;
  cursor: ns-resize;
  opacity: 0
}

.luckysheet-change-size-line {
  border-color: #0188fb;
  border-style: solid;
  z-index: 15;
  display: none
}

.luckysheet-count-show {
  position: absolute;
  z-index: 15;
  background: rgba(76,76,76,.8);
  color: #fff;
  padding: 2px 3px;
  border-radius: 3px;
  transition: all .3s;
  display: none;
  white-space: nowrap
}

.luckysheet-row-count-show {
  text-align: center
}

.luckysheet-row-count-show div {
  writing-mode: vertical-rl;
  writing-mode: vertical-rl;
  -ms-writing-mode: initial
}

.luckysheet-row-count-show div:last-child {
  writing-mode: initial
}

#luckysheet-sheet-list {
  max-height: 60%;
  overflow: auto
}

#luckysheet-sheet-list .luckysheet-cols-menuitem {
  padding-left: 0;
  padding-right: 10px
}

#luckysheet-sheet-list .luckysheet-cols-menuitem .luckysheet-cols-menuitem-content {
  padding-left: 5px
}

#luckysheet-sheet-list .icon {
  width: 15px;
  margin-left: 4px;
  display: inline-block
}

.luckysheet-input-box {
  position: absolute;
  font: normal normal 400 13px arial,sans,sans-serif;
  text-align: left;
  top: -10000px;
  max-height: 9900px;
  max-width: 9900px;
  border: 2px #5292f7 solid;
  padding: 0 2px;
  margin: 0;
  z-index: 15;
  resize: none;
  overflow: auto;
  overflow: initial;
  white-space: pre-wrap;
  outline: 0;
  -webkit-box-shadow: 0 2px 5px rgba(0,0,0,.4);
  -moz-box-shadow: 0 2px 5px rgba(0,0,0,.4);
  box-shadow: 0 2px 5px rgba(0,0,0,.4);
  word-wrap: break-word
}

.luckysheet-cell-input {
  width: 100%;
  height: 100%;
  margin: 0;
  outline: 0;
  cursor: text;
  -webkit-user-modify: read-write-plaintext-only;
  white-space: pre-wrap;
  -webkit-transform: translateZ(0)
}

#luckysheet-rich-text-editor {
  -webkit-user-modify: read-write
}

.luckysheet-input-box-index {
  display: none;
  position: absolute;
  height: 14px;
  line-height: 16px;
  font-size: 12px;
  padding: 1px 6px;
  background-color: #5292f7;
  border-radius: 2px;
  box-shadow: 0 1px 2px rgba(0,0,0,.5);
  color: #fff
}

.luckysheet-modal-dialog {
  -webkit-box-shadow: 0 4px 16px rgba(0,0,0,.2);
  -moz-box-shadow: 0 4px 16px rgba(0,0,0,.2);
  box-shadow: 0 4px 16px rgba(0,0,0,.2);
  background: #fff;
  background-clip: padding-box;
  border: 1px solid #acacac;
  border: 1px solid rgba(0,0,0,.333);
  outline: 0;
  position: absolute;
  color: #000;
  padding: 30px 42px;
  z-index: 100002
}

.luckysheet-modal-dialog-mask {
  position: absolute;
  height: 100%;
  width: 100%;
  background: #fff;
  opacity: .6;
  display: none;
  left: 0;
  top: 0;
  z-index: 1010
}

.luckysheet-modal-dialog-title {
  background-color: #fff;
  color: #000;
  cursor: default;
  font-size: 16px;
  font-weight: 400;
  line-height: 24px;
  margin: 0 0 16px
}

.luckysheet-modal-dialog-title-close {
  height: 11px;
  opacity: .7;
  padding: 17px;
  position: absolute;
  right: 0;
  top: 0;
  width: 11px;
  color: #d4d4d4;
  outline: 0
}

.luckysheet-modal-dialog-chart {
  padding: 20px 10px;
  webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none
}

.luckysheet-modal-dialog-resize {
  position: absolute;
  border: 2px solid #0188fb;
  margin: 0;
  padding: 0;
  top: -2px;
  left: -2px;
  bottom: -2px;
  right: -2px;
  pointer-events: none
}

.luckysheet-modal-dialog-resize-item {
  position: absolute;
  height: 6px;
  width: 6px;
  background: #fff;
  border: 2px solid #0188fb;
  pointer-events: all;
  border-radius: 6px
}

.luckysheet-modal-dialog-resize-item-lt {
  left: -6px;
  top: -6px;
  cursor: se-resize
}

.luckysheet-modal-dialog-resize-item-mt {
  left: 50%;
  top: -6px;
  margin-left: -4px;
  cursor: s-resize
}

.luckysheet-modal-dialog-resize-item-rt {
  right: -6px;
  top: -6px;
  cursor: ne-resize
}

.luckysheet-modal-dialog-resize-item-lm {
  top: 50%;
  left: -6px;
  margin-top: -4px;
  cursor: w-resize
}

.luckysheet-modal-dialog-resize-item-rm {
  top: 50%;
  right: -6px;
  margin-top: -4px;
  cursor: w-resize
}

.luckysheet-modal-dialog-resize-item-lb {
  left: -6px;
  bottom: -6px;
  cursor: ne-resize
}

.luckysheet-modal-dialog-resize-item-mb {
  left: 50%;
  bottom: -6px;
  margin-left: -4px;
  cursor: s-resize
}

.luckysheet-modal-dialog-resize-item-rb {
  right: -6px;
  bottom: -6px;
  cursor: se-resize
}

.luckysheet-modal-dialog-controll {
  position: absolute;
  margin: 0;
  padding: 0;
  right: -35px;
  font-size: 14px;
  top: 0
}

.luckysheet-modal-controll-btn {
  height: 13px;
  padding: 8px;
  width: 13px;
  color: #d4d4d4;
  outline: 0;
  border: 1px solid #b6b6b6;
  display: block;
  background: #fff;
  margin-bottom: 3px;
  cursor: pointer;
  transition: all .2s;
  -moz-transition: all .2s;
  -webkit-transition: all .2s;
  -o-transition: all .2s
}

.luckysheet-modal-controll-btn:hover {
  border: 1px solid #a1a1a1;
  color: #0188fb
}

.luckysheet-modal-controll-btn:active {
  border: 1px solid #bbb;
  background: #efefef;
  color: #0188fb
}

.luckysheet-modal-controll-del {
  font-size: 16px
}

.luckysheet-modal-controll-max-close {
  font-size: 22px;
  width: 42px;
  height: 42px;
  line-height: 42px;
  background: #383838;
  opacity: .7;
  -moz-border-radius: 20px;
  -webkit-border-radius: 20px;
  border-radius: 20px;
  color: #fff;
  position: absolute;
  right: 0;
  top: 0;
  z-index: 100000;
  text-align: center
}

.luckysheet-modal-controll-max-close:hover {
  background: #0188fb;
  cursor: pointer
}

.luckysheet-sort-item-close {
  margin-right: 3px;
  font-size: 14px;
  color: #bbb;
  cursor: pointer
}

.luckysheet-sort-item-close:hover {
  color: #494949
}

.luckysheet-modal-dialog-title-close:hover {
  color: #5e5e5e;
  cursor: pointer
}

.luckysheet-modal-dialog-content {
  background-color: #fff;
  line-height: 1.4em;
  word-wrap: break-word
}

.luckysheet-modal-dialog-buttons {
  margin-top: 10px
}

.luckysheet-modal-dialog-buttons button {
  margin-right: 10px
}

.luckysheet-modal-dialog-title-text span {
  font-family: Arial
}

.luckysheet-sort-modal {
  font-size: 12px
}

.luckysheet-sort-modal label input,.luckysheet-sort-modal label span {
  vertical-align: middle
}

.luckysheet-sort-modal table,.luckysheet-sort-modal>div {
  margin-bottom: 10px
}

.luckysheet-sort-modal table tr {
  margin-bottom: 10px
}

.luckysheet-sort-modal table tr td {
  padding: 5px;
  white-space: nowrap;
  border-top: 1px solid #ffc6c6
}

.luckysheet-sort-modal table tr td>div:first-child {
  margin-bottom: 8px
}

.luckysheet-sort-modal table tr td select {
  max-width: 180px;
  min-width: 50px
}

.luckysheet-sort-modal table tr:first-child td {
  border-top: none
}

.luckysheet-filter-options {
  color: #897bff;
  cursor: pointer;
  position: absolute;
  z-index: 20;
  border: 1px solid #897bff;
  border-radius: 3px;
  top: 3px;
  margin-left: 0;
  display: none;
  padding: 0 4px;
  font-size: 12px;
  height: 15px;
  background: #fff
}

.luckysheet-filter-options:hover {
  color: #fff;
  border: 1px solid #fff;
  background: #897bff
}

.luckysheet-filter-options-active {
  color: #fff;
  border: 1px solid #897bff;
  background: #897bff
}

.luckysheet-flat-menu-button {
  -webkit-border-radius: 2px;
  -moz-border-radius: 2px;
  border-radius: 2px;
  background-color: #f5f5f5;
  background-image: -webkit-linear-gradient(to bottom,#f5f5f5,#f1f1f1);
  background-image: -moz-linear-gradient(to bottom,#f5f5f5,#f1f1f1);
  background-image: -ms-linear-gradient(to bottom,#f5f5f5,#f1f1f1);
  background-image: -o-linear-gradient(to bottom,#f5f5f5,#f1f1f1);
  background-image: linear-gradient(to bottom,#f5f5f5,#f1f1f1);
  border: 1px solid #dcdcdc;
  color: #333;
  cursor: default;
  font-size: 11px;
  font-weight: 700;
  line-height: 27px;
  list-style: none;
  margin: 0 2px;
  min-width: 46px;
  outline: 0;
  padding: 0 18px 0 6px;
  text-align: left;
  text-decoration: none;
  position: relative;
  padding-left: 15px
}

.luckysheet-flat-menu-button:hover {
  -webkit-border-radius: 2px;
  -moz-border-radius: 2px;
  border-radius: 2px;
  background-color: #f5f5f5;
  background-image: -webkit-linear-gradient(to bottom,#f1f1f1,#f5f5f5);
  background-image: -moz-linear-gradient(to bottom,#f1f1f1,#f5f5f5);
  background-image: -ms-linear-gradient(to bottom,#f1f1f1,#f5f5f5);
  background-image: -o-linear-gradient(to bottom,#f1f1f1,#f5f5f5);
  background-image: linear-gradient(to bottom,#f1f1f1,#f5f5f5);
  border: 1px solid #d0d0d0;
  color: #000
}

.luckysheet-flat-menu-button div {
  display: inline-block;
  vertical-align: middle;
  position: absolute;
  right: 15px
}

.luckysheet-data-visualization {
  width: 60%;
  min-width: 860px
}

.luckysheet-data-pivotTable-selection,.luckysheet-data-visualization-selection {
  width: 30%;
  min-width: 200px;
  display: none
}

.luckysheet-data-visualization-chart {
  width: 50%;
  height: 50%
}

.luckysheet-data-visualization-chart .luckysheet-modal-dialog-content {
  width: 100%;
  height: 100%;
  overflow: hidden
}

.luckysheet-datavisual-modal {
  font-size: 12px;
  height: 100%;
  width: 100%
}

.luckysheet-datavisual-left {
  display: inline-block;
  width: 100%;
  height: 100%;
  position: relative;
  overflow: hidden
}

.luckysheet-datavisual-tabs {
  border-bottom: 1px solid #dedede;
  width: 80%;
  height: 26px;
  padding-left: 20px
}

.luckysheet-datavisual-tabs .luckysheet-datavisual-tab {
  padding: 0 5px;
  text-align: center;
  display: inline-block;
  cursor: pointer;
  border: 1px solid #fff;
  border-bottom: none;
  height: 24px;
  line-height: 24px;
  background: #fff;
  color: #777
}

.luckysheet-datavisual-tabs .luckysheet-datavisual-tab:hover {
  color: #000
}

.luckysheet-datavisual-tabs .luckysheet-datavisual-tab-active {
  border: 1px solid #dedede;
  border-bottom: none;
  cursor: default;
  height: 26px;
  color: #000
}

.luckysheet-datavisual-tab-content {
  position: absolute;
  top: 28px;
  bottom: 0;
  width: 100%;
  display: none
}

.luckysheet-datavisual-quick-menu {
  width: 90px;
  overflow: auto;
  margin-top: 5px
}

.luckysheet-datavisual-quick-menu::-webkit-scrollbar {
  display: none
}

.luckysheet-datavisual-quick-menu>div {
  text-align: left;
  padding: 4px 4px;
  border-right: 3px solid #fff;
  color: #777;
  cursor: pointer;
  line-height: 1.4em;
  word-wrap: break-word
}

.luckysheet-datavisual-quick-menu>div:hover {
  color: #000
}

.luckysheet-datavisual-quick-menu>div i {
  width: 15px
}

.luckysheet-datavisual-quick-menu>div:hover i {
  color: #ff7e7e
}

.luckysheet-datavisual-quick-menu>div.luckysheet-datavisual-quick-menu-active {
  border-right: 3px solid #ff7e7e;
  color: #000;
  font-weight: 700
}

.luckysheet-datavisual-quick-menu>div.luckysheet-datavisual-quick-menu-active:hover i {
  color: #000
}

.luckysheet-datavisual-quick-range {
  padding: 5px 0
}

.luckysheet-datavisual-range-container {
  background: #fff;
  border: 1px solid #d9d9d9;
  border-top: 1px solid silver;
  min-width: 20px;
  width: 100%;
  max-width: 200px;
  display: inline-block
}

.luckysheet-datavisual-range-container-focus {
  border: 1px solid #4d90fe;
  box-shadow: inset 0 1px 2px rgba(0,0,0,.3);
  outline: 0
}

.luckysheet-datavisual-range-input,.luckysheet-datavisual-range-input:focus {
  background: 0 0!important;
  border: none!important;
  box-sizing: border-box;
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
  height: 25px;
  margin: 0;
  outline: 0!important;
  padding: 1px 8px!important;
  width: 100%
}

.luckysheet-datavisual-range-button-container {
  overflow: hidden;
  padding: 0 0 0 8px;
  text-align: right;
  width: 21px
}

.luckysheet-datavisual-range-button-container div {
  padding: 2px 10px 0 10px;
  font-size: 18px;
  cursor: pointer;
  color: #6598f3
}

.luckysheet-datavisual-range-button-container div:hover {
  color: #ff7e7e
}

.luckysheet-datavisual-quick-m {
  margin-top: 5px
}

.luckysheet-datavisual-quick-list {
  left: 90px;
  right: 0;
  bottom: 0;
  top: 110px;
  position: absolute;
  overflow: auto;
  border-top: 1px solid #e5e5e5;
  padding: 5px 3px 35px 3px
}

.luckysheet-datavisual-quick-list-title {
  padding: 4px 6px;
  background: #e5e5e5;
  margin-top: 10px
}

.luckysheet-datavisual-quick-list-ul {
  overflow: hidden
}

.luckysheet-datavisual-quick-list-item {
  display: inline-block;
  margin: 5px 8px;
  border: 1px solid #dadada;
  width: 100px;
  height: 80px
}

.luckysheet-datavisual-quick-list-item:hover {
  border: 1px solid #ff7e7e;
  box-shadow: 0 0 20px #ff7e7e
}

.luckysheet-datavisual-quick-list-item img {
  display: inline-block;
  width: 100px;
  height: 80px
}

.luckysheet-datavisual-quick-list-item-active {
  border: 1px solid #6598f3;
  box-shadow: 0 0 20px #6598f3
}

.jfk-tooltip {
  z-index: 300000
}

.jfk-tooltip-hide {
  -webkit-transition: visibility .13s,opacity .13s ease-out,left 0 linear .13s,top 0 linear .13s;
  -moz-transition: visibility .13s,opacity .13s ease-out,left 0 linear .13s,top 0 linear .13s;
  -o-transition: visibility .13s,opacity .13s ease-out,left 0 linear .13s,top 0 linear .13s;
  transition: visibility .13s,opacity .13s ease-out,left 0 linear .13s,top 0 linear .13s;
  opacity: 0;
  left: 20px!important;
  top: 20px!important;
  visibility: hidden!important
}

.jfk-tooltip {
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
  -webkit-transition: visibility 0,opacity .13s ease-in;
  -moz-transition: visibility 0,opacity .13s ease-in;
  -o-transition: visibility 0,opacity .13s ease-in;
  transition: visibility 0,opacity .13s ease-in;
  background-color: #2a2a2a;
  border: 1px solid #fff;
  color: #fff;
  cursor: default;
  display: block;
  font-size: 11px;
  font-weight: 700;
  margin-left: -1px;
  opacity: 1;
  padding: 7px 9px;
  position: absolute;
  visibility: visible;
  white-space: pre-wrap;
  word-break: break-all;
  word-break: break-word
}

.jfk-tooltip-arrowup {
  top: -6px
}

.jfk-tooltip-arrow {
  pointer-events: none;
  position: absolute
}

.jfk-tooltip-arrow .jfk-tooltip-arrowimplafter {
  border: 5px solid
}

.jfk-tooltip-arrow .jfk-tooltip-arrowimplbefore {
  border: 6px solid
}

.jfk-tooltip-arrow .jfk-tooltip-arrowimplafter,.jfk-tooltip-arrow .jfk-tooltip-arrowimplbefore {
  content: '';
  display: block;
  height: 0;
  position: absolute;
  width: 0
}

.jfk-tooltip-arrowup .jfk-tooltip-arrowimplafter {
  border-top-width: 0;
  top: 1px
}

.jfk-tooltip-arrowdown .jfk-tooltip-arrowimplafter,.jfk-tooltip-arrowup .jfk-tooltip-arrowimplafter {
  border-color: #2a2a2a transparent;
  left: -5px
}

.jfk-tooltip-arrowup .jfk-tooltip-arrowimplbefore {
  border-top-width: 0
}

.jfk-tooltip-arrowdown .jfk-tooltip-arrowimplbefore,.jfk-tooltip-arrowup .jfk-tooltip-arrowimplbefore {
  border-color: #fff transparent;
  left: -6px
}

.luckysheet-datavisual-config {
  position: relative;
  width: 100%;
  height: 97%;
  overflow: auto;
  top: 0
}

.luckysheet-datavisual-config input {
  outline: 0
}

.luckysheet-datavisual-config .luckysheet-datavisual-accordion-title {
  position: relative;
  width: 97%;
  height: 33px;
  background: #f5f5f5;
  border: 1px solid #e5e5e5;
  margin-top: 30px;
  line-height: 30px;
  font-weight: 700;
  color: #d14836;
  cursor: pointer
}

.luckysheet-datavisual-config .luckysheet-datavisual-accordion-title:hover {
  background: #efefef;
  border: 1px solid #e0e0e0
}

.luckysheet-datavisual-config .luckysheet-datavisual-accordion-content {
  position: relative;
  width: 97%;
  border: 1px solid #e5e5e5;
  border-top: 1px solid #fff;
  display: none;
  color: #505050;
  padding-bottom: 20px
}

.luckysheet-datavisual-config-input,.luckysheet-datavisual-config-input-no {
  background: #fff;
  border: 1px solid #d9d9d9;
  border-top: 1px solid silver;
  min-width: 50px;
  width: 90%;
  display: inline-block;
  height: 24px;
  line-height: 24px;
  padding: 3px
}

.luckysheet-datavisual-config-input-no:focus,.luckysheet-datavisual-config-input:focus {
  border: 1px solid #4d90fe;
  box-shadow: inset 0 1px 2px rgba(0,0,0,.3);
  outline: 0
}

.luckysheet-datavisual-content-row {
  margin-left: 15px;
  margin-bottom: 5px;
  margin-top: 15px;
  height: 30px;
  line-height: 30px
}

.luckysheet-datavisual-content-column {
  display: inline-block;
  position: relative
}

.luckysheet-datavisual-content-column-title {
  text-align: left;
  font-size: 14px
}

.luckysheet-datavisual-content-column-right {
  text-align: right
}

.luckysheet-datavisual-content-rowsplit {
  height: 5px;
  border-top: 1px solid #e5e5e5;
  width: 100%;
  margin-top: 25px
}

.luckysheet-datavisual-content-rowsplit-sub {
  height: 2px;
  border-top: 1px dashed #e5e5e5;
  width: 90%;
  margin: 0 auto;
  margin-top: 18px;
  text-align: center
}

.sp-replacer {
  padding: 2px;
  border: solid 1px #e5e5e5;
  background: #f5f5f5
}

.ui-visual-focus {
  box-shadow: none
}

.luckysheet-datavisual-config-slider,.luckysheet-datavisual-config-slider-range {
  width: 70%;
  display: inline-block
}

.luckysheet-datavisual-config-slider-range .luckysheet-slider-handle {
  width: 45px;
  height: 26px;
  top: 50%;
  margin-top: -13px;
  text-align: center;
  line-height: 26px
}

.luckysheet-datavisual-content-row-subtitle {
  display: none
}

.ui-selectmenu-button.ui-button {
  text-align: left;
  white-space: nowrap;
  width: 48%
}

.luckysheet-datavisual-content-column-italic {
  font-style: italic;
  font-weight: 700;
  font-family: 'Times New Roman',Times,serif
}

.luckysheetChartAxisShow {
  display: none
}

.luckysheet-datavisual-chart-axistitle-show {
  display: none
}

.luckysheetChartseriesShow {
  display: none
}

#luckysheetswichxy-button,#piecutselect-button {
  width: 70%
}

.ui-selectmenu-menu .ui-menu.customicons .ui-menu-item-wrapper {
  padding: .5em 0 .5em 3em
}

.ui-selectmenu-menu .ui-menu.customicons .ui-menu-item .ui-icon {
  height: 26px;
  width: 26px;
  top: .1em;
  background-image: none
}

#luckysheetscatterselectshow-menu .ui-state-active,#luckysheetswichseries-menu .ui-state-active,#pie0cutselect-menu .ui-state-active,#pie1cutselect-menu .ui-state-active,#pie2cutselect-menu .ui-state-active {
  border: 1px solid #f5f5f5;
  background: #f5f5f5;
  color: #333
}

.ui-front {
  z-index: 100003
}

.luckysheet-datavisual-skin-menu {
  top: 5px;
  position: absolute;
  left: 0;
  width: 90%;
  height: 30px
}

#luckysheet-chart-theme-content {
  height: 21px;
  width: 120px
}

.luckysheet-datavisual-skin-c {
  position: absolute;
  left: 0;
  top: 38px;
  bottom: 0;
  width: 100%;
  overflow: auto
}

.luckysheet-datavisual-skin-c .luckysheet-datavisual-skin-item {
  display: inline-block;
  width: 46%;
  height: 152px;
  margin-right: 5px;
  border: 4px solid #efefef;
  border-radius: 4px;
  position: relative;
  cursor: pointer
}

.luckysheet-datavisual-skin-c .luckysheet-datavisual-skin-item-more {
  display: inline-block;
  width: 94%;
  height: 32px;
  position: relative;
  cursor: pointer;
  font-size: 20px;
  line-height: 32px;
  margin-bottom: 20px;
  text-align: center
}

.luckysheet-datavisual-skin-item .luckysheet-datavisual-skin-canvas,.luckysheet-datavisual-skin-item .luckysheet-datavisual-skin-cover {
  position: absolute;
  width: 100%;
  height: 100%;
  bottom: 0
}

.luckysheet-datavisual-skin-item .luckysheet-datavisual-skin-cover {
  background-color: rgba(0,0,0,.4);
  color: #fff;
  font-size: 14px;
  height: 30%;
  transition: opacity .15s ease;
  -moz-transition: opacity .15s ease;
  -webkit-transition: opacity .15s ease;
  -o-transition: opacity .15s ease
}

.luckysheet-datavisual-skin-item:hover .luckysheet-datavisual-skin-cover {
  opacity: 1;
  z-index: 2
}

.luckysheet-datavisual-skin-cover .luckysheet-datavisual-skin-cover-txt {
  position: absolute;
  width: 80%;
  height: 80%;
  top: 10%;
  left: 10%;
  text-align: center
}

.luckysheet-chart-point-config {
  position: relative;
  width: 100%;
  height: 100%;
  margin: 0;
  font-size: 12px
}

.luckysheet-chart-point-config-set {
  position: absolute;
  width: 60%;
  height: 100%;
  left: 0;
  top: 0
}

.luckysheet-chart-point-config-left {
  position: absolute;
  height: 100%;
  width: 50%;
  left: 0;
  top: 0
}

.luckysheet-chart-point-config-left-top {
  position: absolute;
  top: 0;
  height: 120px;
  width: 100%
}

.luckysheet-chart-point-searchcondition {
  position: absolute;
  top: 10px;
  bottom: 10px;
  left: 10px;
  right: 10px
}

.luckysheet-chart-point-config-left-mid {
  position: absolute;
  top: 120px;
  height: 25px;
  width: 100%;
  text-align: left;
  margin-left: 20px;
  line-height: 35px
}

.luckysheet-chart-point-config-left-mid span {
  color: #00f;
  cursor: pointer;
  text-decoration: underline;
  font-size: 12px
}

.luckysheet-chart-point-config-left-bottom {
  position: absolute;
  top: 0;
  bottom: 0;
  margin-top: 145px;
  width: 100%
}

.luckysheet-chart-point-searchitem-c {
  position: absolute;
  width: 100%;
  height: 100%;
  overflow: hidden;
  overflow-y: auto;
  cursor: default
}

.luckysheet-chart-point-searchitem {
  display: inline-block;
  margin-left: 5px;
  margin-top: 5px;
  width: 90px;
  border: 2px solid #f5f5f5;
  background: #fff;
  text-align: center;
  padding: 5px 0;
  user-select: none;
  cursor: default;
  position: relative
}

.luckysheet-chart-point-searchitem-selected {
  position: absolute;
  color: #616161;
  left: -6px;
  top: -10px;
  font-size: 20px;
  display: none;
  font-weight: 400
}

.luckysheet-chart-point-searchitem-active {
  box-shadow: 0 0 4px #656565
}

.luckysheet-chart-point-searchitem-active .luckysheet-chart-point-searchitem-selected {
  display: block
}

.luckysheet-chart-point-searchitem-name {
  font-size: 12px;
  cursor: default;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis
}

.luckysheet-chart-point-searchitem-dim {
  font-size: 12px;
  opacity: .7;
  cursor: default;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis
}

#luckysheet-chart-point-selectedhelp {
  pointer-events: none;
  position: absolute;
  border: 1px dotted #535353
}

.luckysheet-chart-point-config-right {
  position: absolute;
  height: 100%;
  width: 50%;
  top: 0;
  right: 0
}

.luckysheet-chart-point-itemconfig {
  position: absolute;
  top: 10px;
  bottom: 10px;
  left: 10px;
  right: 10px;
  overflow: auto
}

.luckysheet-chart-point-config-chart {
  position: absolute;
  width: 40%;
  height: 100%;
  right: 0;
  top: 0
}

.luckysheet-chart-point-config-chart-c {
  width: 100%;
  height: 80%;
  top: 10%;
  position: relative
}

@media (max-width: 776px) {
  .luckysheet-chart-point-config-set {
      width:90%
  }

  .luckysheet-chart-point-config-chart {
      width: 10%
  }
}

@media (min-width: 768px) {
  .luckysheet-chart-point-config-set {
      width:80%
  }

  .luckysheet-chart-point-config-chart {
      width: 20%
  }
}

@media (min-width: 1024px) {
  .luckysheet-chart-point-config-set {
      width:70%
  }

  .luckysheet-chart-point-config-chart {
      width: 30%
  }
}

@media (min-width: 1280px) {
  .luckysheet-chart-point-config-set {
      width:60%
  }

  .luckysheet-chart-point-config-chart {
      width: 40%
  }
}

@media (min-width: 1680px) {
  .luckysheet-chart-point-config-set {
      width:50%
  }

  .luckysheet-chart-point-config-chart {
      width: 50%
  }
}

.luckysheet-modal-dialog-slider {
  top: 1px;
  bottom: 1px;
  position: absolute;
  right: 0;
  width: 260px;
  border: 1px solid #e5e5e5;
  z-index: 1004;
  box-shadow: 0 2px 4px rgba(0,0,0,.2);
  -webkit-box-shadow: 0 2px 4px rgba(0,0,0,.2);
  -moz-box-shadow: 0 2px 4px rgba(0,0,0,.2);
  -moz-user-select: none;
  -khtml-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none
}

.luckysheet-modal-dialog-slider .luckysheet-modal-dialog-slider-title {
  background: #333;
  color: #fff;
  height: 39px;
  width: 100%;
  position: absolute;
  top: 0;
  left: 0;
  line-height: 39px;
  font-size: 13px
}

.luckysheet-modal-dialog-slider .luckysheet-modal-dialog-slider-title>span:first-child {
  margin-left: 5px;
  font-weight: 700
}

.luckysheet-modal-dialog-slider .luckysheet-modal-dialog-slider-title>span:last-child {
  position: relative;
  float: right;
  margin-right: 20px;
  cursor: pointer
}

.luckysheet-modal-dialog-slider-content {
  background: #efefef;
  margin-top: 39px;
  width: 100%;
  position: absolute;
  top: 0;
  bottom: 0;
  font-size: 12px
}

.luckysheet-modal-dialog-slider-range {
  background: #e1e1de;
  color: #1b1b19;
  height: 40px;
  font-size: 13px;
  line-height: 40px
}

.luckysheet-modal-dialog-slider-range>div:first-child {
  font-weight: 700;
  overflow: hidden;
  text-overflow: ellipsis;
  float: left;
  max-width: 170px;
  margin-right: 10px;
  margin-left: 5px;
  white-space: nowrap
}

.luckysheet-modal-dialog-slider-range>div:last-child {
  color: #00f;
  cursor: pointer;
  float: left
}

.luckysheet-modal-dialog-slider-list {
  width: 250px;
  height: 320px;
  overflow-y: scroll;
  margin: 5px 0;
  margin-left: 5px;
  border-top: 1px solid #e5e5e5;
  border-bottom: 1px solid #e5e5e5;
  background: #fff
}

.luckysheet-modal-dialog-slider-list-title {
  height: 20px;
  line-height: 25px;
  padding: 0 5px
}

.luckysheet-modal-dialog-slider-list .luckysheet-modal-dialog-slider-list-item {
  padding: 0 4px;
  position: relative;
  width: 228px;
  height: 25px;
  user-select: none;
  border: 1px solid #fff
}

.luckysheet-modal-dialog-slider-list .luckysheet-modal-dialog-slider-list-item:hover {
  background: #fff6cb;
  border: 1px solid #ffe463
}

.luckysheet-modal-dialog-slider-list .luckysheet-slider-list-item-name {
  cursor: pointer;
  height: 25px;
  line-height: 25px;
  cursor: move;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  position: absolute;
  left: 22px;
  right: 40px;
  top: 0
}

.luckysheet-modal-dialog-slider-list .luckysheet-slider-list-item-selected {
  width: 20px;
  cursor: pointer;
  text-align: center;
  position: absolute;
  left: 0;
  top: 0;
  height: 25px
}

.luckysheet-modal-dialog-slider-list .luckysheet-slider-list-item-selected i {
  margin-top: 4px;
  font-size: 16px
}

.luckysheet-modal-dialog-slider-list .luckysheet-slider-list-item-selected div {
  border: 1px solid #9c9c9c;
  top: 4px;
  left: 1px;
  position: absolute;
  height: 14px;
  width: 14px;
  -moz-box-shadow: 1px 1px 1px #dbdbdb inset;
  -webkit-box-shadow: 1px 1px 1px #dbdbdb inset;
  box-shadow: 1px 1px 1px #dbdbdb inset
}

.luckysheet-modal-dialog-slider-list .luckysheet-slider-list-item-selected div:hover {
  border: 1px solid #5e5e5e
}

.luckysheet-modal-dialog-slider-list .luckysheet-slider-list-item-filtered {
  width: 20px;
  cursor: pointer;
  text-align: center;
  position: absolute;
  right: 20px;
  top: 2px;
  height: 25px;
  display: none
}

.luckysheet-modal-dialog-slider-list .luckysheet-slider-list-item-filtered i {
  margin-top: 2px;
  font-size: 16px
}

.luckysheet-modal-dialog-slider-list .luckysheet-slider-list-item-filtered:hover i {
  color: #fb8686
}

.luckysheet-modal-dialog-slider-list .luckysheet-slider-list-item-filtered i.fa-times {
  right: 0;
  bottom: 3px;
  color: red;
  font-size: 9px;
  position: absolute
}

.luckysheet-modal-dialog-slider-list .luckysheet-slider-list-item-filter {
  width: 20px;
  cursor: pointer;
  text-align: center;
  position: absolute;
  right: 0;
  top: 0;
  height: 25px
}

.luckysheet-modal-dialog-slider-list .luckysheet-slider-list-item-filter i {
  margin-top: 2px;
  font-size: 16px
}

.luckysheet-modal-dialog-slider-list .luckysheet-slider-list-item-filter:hover i {
  color: #fb8686
}

.luckysheet-modal-dialog-slider-config-c {
  width: 100%;
  position: absolute;
  margin-top: 390px;
  top: 0;
  bottom: 3px
}

.luckysheet-modal-dialog-slider-config {
  height: 50%;
  width: 50%;
  position: absolute
}

.luckysheet-modal-dialog-slider-config>div:first-child {
  color: #1b1b19;
  font-size: 13px;
  height: 20px;
  line-height: 20px;
  padding-left: 5px
}

.luckysheet-modal-dialog-slider-config>div:first-child span {
  font-weight: 700;
  font-weight: 700;
  overflow: hidden
}

.luckysheet-modal-dialog-slider-config .luckysheet-modal-dialog-slider-config-list {
  position: absolute;
  margin-top: 22px;
  margin-left: 5px;
  left: 0;
  right: 5px;
  top: 0;
  bottom: 3px;
  border: 1px solid #e5e5e5;
  user-select: none;
  overflow-y: auto;
  background: #fff
}

.luckysheet-modal-dialog-slider-config-list .luckysheet-modal-dialog-slider-config-item {
  position: relative;
  height: 19px;
  line-height: 19px;
  font-size: 12px;
  border: 1px solid #88adfd;
  background: #aac1fe;
  margin: 2px
}

.luckysheet-modal-dialog-slider-config-list .luckysheet-modal-dialog-slider-config-item:hover {
  border: 1px solid #0188fb;
  background: #5f9afc
}

.luckysheet-modal-dialog-slider-config-item-txt {
  position: absolute;
  height: 100%;
  left: 5px;
  right: 25px;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  cursor: move
}

.luckysheet-modal-dialog-slider-config-item-icon {
  position: absolute;
  height: 100%;
  width: 15px;
  right: 0;
  top: -4px;
  cursor: pointer;
  font-size: 14px
}

.luckysheet-modal-dialog-slider-config-item-icon:hover {
  color: #fa7272
}

.luckysheet-modal-dialog-config-filter {
  top: 0;
  left: 0
}

.luckysheet-modal-dialog-config-column {
  top: 0;
  left: 50%
}

.luckysheet-modal-dialog-config-row {
  top: 50%;
  left: 0
}

.luckysheet-modal-dialog-config-value {
  top: 50%;
  left: 50%
}

#luckysheet-modal-dialog-slider-pivot-move {
  position: absolute;
  max-width: 100px;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  background: #fff;
  border: 1px dotted #000;
  color: #000;
  font-size: 14px;
  opacity: .6;
  z-index: 1005;
  padding: 3px 8px;
  pointer-events: none;
  user-select: none
}

.luckysheet-modal-dialog-slider-chart {
  width: 445px
}

.luckysheet-modal-dialog-slider-chart .luckysheet-modal-dialog-slider-title {
  background: #b94045
}

.luckysheet-modal-dialog-slider-chart .luckysheet-modal-dialog-slider-content {
  background: #fff
}

#luckysheet-dialog-pivotTable-clearitem {
  color: #00f;
  cursor: pointer;
  float: right;
  margin-right: 30px
}

.luckysheet-freezebar-drop,.luckysheet-freezebar-handle {
  position: absolute;
  z-index: 999
}

.luckysheet-freezebar-vertical-handle {
  width: 4px;
  display: none
}

.luckysheet-freezebar-vertical-drop {
  width: 4px
}

.luckysheet-freezebar-active .luckysheet-freezebar-vertical-handle {
  display: block;
  z-index: 1003
}

.luckysheet-freezebar-vertical-handle-bar {
  width: 2px;
  background: #dbe5f7;
  border-color: #a5c6fe;
  border-style: solid;
  border-width: 0 1px;
  opacity: .45;
  margin-top: 19px;
  top: 0;
  bottom: 0
}

.luckysheet-freezebar-vertical-handle-title {
  width: 4px;
  background: #9dbefb;
  opacity: .8;
  height: 19px;
  top: 0
}

.luckysheet-freezebar-drop-bar,.luckysheet-freezebar-handle-bar {
  position: absolute;
  z-index: 7
}

.luckysheet-freezebar-vertical-drop-bar {
  width: 2px;
  background: rgba(0,0,0,.45);
  border-width: 2px 1px 2px 2px;
  margin-top: 19px;
  top: 0;
  bottom: 0
}

.luckysheet-freezebar-vertical-drop-title {
  width: 2px;
  background: #bcbdbc;
  height: 19px;
  top: 0
}

.luckysheet-freezebar-active .luckysheet-freezebar-vertical-drop-bar,.luckysheet-freezebar-hover .luckysheet-freezebar-vertical-drop-bar {
  background: #c1c1c1;
  width: 4px
}

.luckysheet-freezebar-active .luckysheet-freezebar-vertical-drop-title,.luckysheet-freezebar-hover .luckysheet-freezebar-vertical-drop-title {
  background: #5d88db;
  width: 4px
}

.luckysheet-freezebar-horizontal-handle {
  height: 4px;
  display: none
}

.luckysheet-freezebar-horizontal-drop {
  height: 4px
}

.luckysheet-freezebar-active .luckysheet-freezebar-horizontal-handle {
  display: block;
  z-index: 1003
}

.luckysheet-freezebar-horizontal-handle-bar {
  height: 2px;
  background: #dbe5f7;
  border-color: #a5c6fe;
  border-style: solid;
  border-width: 1px 0;
  opacity: .45;
  margin-left: 45px;
  left: 0;
  right: 0
}

.luckysheet-freezebar-horizontal-handle-title {
  height: 4px;
  background: #9dbefb;
  opacity: .8;
  width: 45px;
  left: 0
}

.luckysheet-freezebar-horizontal-drop-bar {
  height: 2px;
  overflow: hidden;
  background: rgba(0,0,0,.45);
  border-width: 2px 2px 1px 2px;
  margin-left: 45px;
  left: 0;
  right: 0
}

.luckysheet-freezebar-horizontal-drop-title {
  height: 2px;
  background: #bcbdbc;
  width: 45px;
  left: 0
}

.luckysheet-freezebar-active .luckysheet-freezebar-horizontal-drop-bar,.luckysheet-freezebar-hover .luckysheet-freezebar-horizontal-drop-bar {
  background: #c1c1c1;
  height: 4px
}

.luckysheet-freezebar-active .luckysheet-freezebar-horizontal-drop-title,.luckysheet-freezebar-hover .luckysheet-freezebar-horizontal-drop-title {
  background: #5d88db;
  height: 4px
}

#luckysheet-functionbox-container {
  height: 100%;
  padding-left: 10px;
  overflow: hidden;
  position: absolute;
  padding: 0;
  top: 0;
  left: 185px;
  right: 10px;
  border-left: 1px solid #e5e5e5
}

#luckysheet-functionbox-container>div {
  height: 100%;
  overflow-x: hidden;
  overflow-y: auto;
  position: relative
}

#luckysheet-functionbox {
  bottom: 6px;
  left: 0;
  position: absolute;
  right: 0;
  top: 6px;
  resize: none;
  font-family: arial,sans,sans-serif;
  font-size: 14px;
  line-height: 14px;
  background-color: #fff;
  padding: 0 5px
}

#luckysheet-functionbox .luckysheet-functionbox-cell-input {
  word-wrap: break-word;
  -webkit-nbsp-mode: space;
  -webkit-line-break: after-white-space
}

.luckysheet-functionbox-cell-input {
  width: 100%;
  height: 100%;
  margin: 0;
  outline: 0;
  cursor: text;
  -webkit-user-modify: read-write-plaintext-only;
  white-space: pre-wrap;
  -webkit-transform: translateZ(0);
  background-color: #fff
}

.luckysheet-formula-text-color {
  color: #000
}

.luckysheet-formula-text-string {
  color: #228b22
}

.luckysheet-formula-search-c {
  position: absolute;
  left: 50%;
  top: 50%;
  border: 1px solid rgba(0,0,0,.2);
  box-shadow: 0 2px 4px rgba(0,0,0,.2);
  color: #535353;
  font-size: 12px;
  background: #fff;
  z-index: 1003;
  width: 300px;
  display: none
}

.luckysheet-formula-search-c .luckysheet-formula-search-item {
  background: #fff;
  padding: 5px 10px;
  cursor: pointer
}

.luckysheet-formula-search-c .luckysheet-formula-search-item .luckysheet-formula-search-detail {
  display: none;
  color: #444
}

.luckysheet-formula-search-c .luckysheet-formula-search-item .luckysheet-formula-search-func {
  color: #222;
  font-size: 14px
}

.luckysheet-formula-search-c .luckysheet-formula-search-item-active {
  display: block;
  border-top: 1px solid #ebebeb;
  border-bottom: 1px solid #ebebeb;
  background: #f5f5f5
}

.luckysheet-formula-search-c .luckysheet-formula-search-item-active .luckysheet-formula-search-detail {
  display: block
}

.luckysheet-formula-help-c {
  display: none;
  position: absolute;
  left: 20%;
  top: 20%;
  border: 1px solid rgba(0,0,0,.2);
  box-shadow: 0 2px 4px rgba(0,0,0,.2);
  color: #535353;
  font-size: 12px;
  background: #fff;
  z-index: 1003;
  width: 300px
}

.luckysheet-formula-help-c .luckysheet-formula-help-content {
  max-height: 300px;
  overflow-y: scroll
}

.luckysheet-formula-help-content-example {
  margin-top: 5px
}

.luckysheet-formula-help-title {
  display: block;
  border-top: 1px solid #ebebeb;
  border-bottom: 1px solid #ebebeb;
  background: #f5f5f5;
  padding: 2px 10px;
  font-size: 14px
}

.luckysheet-formula-help-title-formula {
  width: 250px;
  word-break: break-word
}

.luckysheet-arguments-help-section {
  margin-top: 5px;
  margin-bottom: 5px;
  color: #222
}

.luckysheet-arguments-help-section-title {
  padding: 1px 10px;
  color: #666
}

.luckysheet-arguments-help-parameter-content {
  padding: 1px 10px;
  display: inline-block;
  word-wrap: break-word
}

.luckysheet-arguments-help-formula {
  padding: 1px 10px;
  font-size: 14px
}

.luckysheet-arguments-help-parameter-active {
  background-color: #fff9b2
}

.luckysheet-formula-help-collapse {
  position: absolute;
  top: 0;
  right: 25px;
  font-size: 16px;
  cursor: pointer;
  color: #bbb
}

.luckysheet-formula-help-close {
  position: absolute;
  top: 0;
  right: 5px;
  font-size: 16px;
  cursor: pointer;
  color: #bbb
}

.luckysheet-formula-help-close:hover,.luckysheet-formula-help-collapse:hover {
  color: #555
}

.luckysheetLoader {
  font-size: 20px;
  width: 1em;
  height: 1em;
  border-radius: 50%;
  text-indent: -9999em;
  position: absolute;
  top: 50%;
  left: 50%;
  animation: load-effect 1s infinite linear
}

.luckysheetLoaderGif {
  width: 8em;
  height: 8em;
  position: absolute;
  top: 50%;
  left: 50%;
  -ms-transform: translate(-50%,-100%);
  -moz-transform: translate(-50%,-100%);
  -o-transform: translate(-50%,-100%);
  transform: translate(-50%,-100%);
  background-image: url(loading.gif);
  background-repeat: no-repeat;
  background-position: center;
  background-size: 100% 100%
}

@keyframes load-effect {
  0% {
      box-shadow: 0 -3em 0 .2em #0188fb,2em -2em 0 0 #0188fb,3em 0 0 -.5em #0188fb,2em 2em 0 -.5em #0188fb,0 3em 0 -.5em #0188fb,-2em 2em 0 -.5em #0188fb,-3em 0 0 -.5em #0188fb,-2em -2em 0 0 #0188fb
  }

  12.5% {
      box-shadow: 0 -3em 0 0 #0188fb,2em -2em 0 .2em #0188fb,3em 0 0 0 #0188fb,2em 2em 0 -.5em #0188fb,0 3em 0 -.5em #0188fb,-2em 2em 0 -.5em #0188fb,-3em 0 0 -.5em #0188fb,-2em -2em 0 -.5em #0188fb
  }

  25% {
      box-shadow: 0 -3em 0 -.5em #0188fb,2em -2em 0 0 #0188fb,3em 0 0 .2em #0188fb,2em 2em 0 0 #0188fb,0 3em 0 -.5em #0188fb,-2em 2em 0 -.5em #0188fb,-3em 0 0 -.5em #0188fb,-2em -2em 0 -.5em #0188fb
  }

  37.5% {
      box-shadow: 0 -3em 0 -.5em #0188fb,2em -2em 0 -.5em #0188fb,3em 0 0 0 #0188fb,2em 2em 0 .2em #0188fb,0 3em 0 0 #0188fb,-2em 2em 0 -.5em #0188fb,-3em 0 0 -.5em #0188fb,-2em -2em 0 -.5em #0188fb
  }

  50% {
      box-shadow: 0 -3em 0 -.5em #0188fb,2em -2em 0 -.5em #0188fb,3em 0 0 -.5em #0188fb,2em 2em 0 0 #0188fb,0 3em 0 .2em #0188fb,-2em 2em 0 0 #0188fb,-3em 0 0 -.5em #0188fb,-2em -2em 0 -.5em #0188fb
  }

  62.5% {
      box-shadow: 0 -3em 0 -.5em #0188fb,2em -2em 0 -.5em #0188fb,3em 0 0 -.5em #0188fb,2em 2em 0 -.5em #0188fb,0 3em 0 0 #0188fb,-2em 2em 0 .2em #0188fb,-3em 0 0 0 #0188fb,-2em -2em 0 -.5em #0188fb
  }

  75% {
      box-shadow: 0 -3em 0 -.5em #0188fb,2em -2em 0 -.5em #0188fb,3em 0 0 -.5em #0188fb,2em 2em 0 -.5em #0188fb,0 3em 0 -.5em #0188fb,-2em 2em 0 0 #0188fb,-3em 0 0 .2em #0188fb,-2em -2em 0 0 #0188fb
  }

  87.5% {
      box-shadow: 0 -3em 0 0 #0188fb,2em -2em 0 -.5em #0188fb,3em 0 0 -.5em #0188fb,2em 2em 0 -.5em #0188fb,0 3em 0 -.5em #0188fb,-2em 2em 0 0 #0188fb,-3em 0 0 0 #0188fb,-2em -2em 0 .2em #0188fb
  }

  100% {
      box-shadow: 0 -3em 0 .2em #0188fb,2em -2em 0 0 #0188fb,3em 0 0 -.5em #0188fb,2em 2em 0 -.5em #0188fb,0 3em 0 -.5em #0188fb,-2em 2em 0 -.5em #0188fb,-3em 0 0 -.5em #0188fb,-2em -2em 0 0 #0188fb
  }
}

.luckysheetpopover {
  position: absolute;
  background: rgba(0,0,0,.65);
  color: #fff;
  font-size: 18px;
  padding: 20px 100px;
  text-align: center;
  z-index: 10000;
  border-radius: 4px;
  user-select: none;
  display: none
}

.luckysheetpopover .luckysheetpopover-btn {
  position: absolute;
  right: 10px;
  top: 50%;
  margin-top: -12px;
  border: 1px solid #fff;
  border-radius: 4px;
  padding: 2px 4px;
  cursor: pointer;
  font-size: 14px
}

.luckysheetpopover .luckysheetpopover-btn:hover {
  border: 1px solid #fea2a2;
  color: #fea2a2
}

.luckysheetPaintCursor {
  cursor: url(paint_24px.ico),auto
}

#luckysheet-search-replace .tabBox {
  margin-top: 20px;
  font-size: 0
}

#luckysheet-search-replace .tabBox span {
  display: inline-block;
  text-align: center;
  width: 100px;
  border: 1px solid #d4d4d4;
  font-size: 14px;
  line-height: 2
}

#luckysheet-search-replace .tabBox span.on {
  background-color: #8c89fe;
  border-color: #726efe;
  color: #fff
}

#luckysheet-search-replace .ctBox {
  padding: 5px 10px;
  border: solid 1px #d4d4d4;
  font-size: 14px
}

#luckysheet-search-replace .inputBox {
  height: 90px;
  position: relative
}

#luckysheet-search-replace .inputBox .textboxs {
  height: 30px;
  line-height: 30px
}

#luckysheet-search-replace .inputBox .checkboxs {
  height: 90px;
  position: absolute;
  right: 0;
  top: 0
}

#luckysheet-search-replace .inputBox .checkboxs div {
  height: 30px;
  line-height: 30px
}

#luckysheet-search-replace .inputBox .checkboxs input[type=checkbox] {
  float: left;
  margin-top: 9px
}

#luckysheet-search-replace .btnBox {
  margin-top: 10px
}

#luckysheet-search-replace .btnBox button {
  margin: 0 2.5px
}

#luckysheet-search-replace #searchAllbox {
  height: 210px;
  border: 1px solid #d4d4d4;
  margin-top: 10px;
  overflow-y: auto;
  position: relative
}

#luckysheet-search-replace #searchAllbox .boxTitle {
  width: 100%;
  height: 30px;
  line-height: 29px;
  padding: 0 5px;
  background-color: #fff;
  border-bottom: 1px solid #d4d4d4;
  box-sizing: border-box;
  position: sticky;
  left: 0;
  top: 0
}

#luckysheet-search-replace #searchAllbox .boxTitle span {
  display: inline-block;
  text-align: center
}

#luckysheet-search-replace #searchAllbox .boxTitle span:nth-of-type(1) {
  width: 25%
}

#luckysheet-search-replace #searchAllbox .boxTitle span:nth-of-type(2) {
  width: 25%
}

#luckysheet-search-replace #searchAllbox .boxTitle span:nth-of-type(3) {
  width: 50%
}

#luckysheet-search-replace #searchAllbox .boxMain .boxItem {
  height: 30px;
  line-height: 29px;
  border-bottom: 1px solid #d4d4d4;
  padding: 0 5px;
  box-sizing: border-box
}

#luckysheet-search-replace #searchAllbox .boxMain .boxItem.on {
  background-color: #8c89fe;
  color: #fff
}

#luckysheet-search-replace #searchAllbox .boxMain .boxItem span {
  display: block;
  text-align: center;
  float: left
}

#luckysheet-search-replace #searchAllbox .boxMain .boxItem span:nth-of-type(1) {
  width: 25%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap
}

#luckysheet-search-replace #searchAllbox .boxMain .boxItem span:nth-of-type(2) {
  width: 25%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap
}

#luckysheet-search-replace #searchAllbox .boxMain .boxItem span:nth-of-type(3) {
  width: 50%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap
}

#luckysheet-search-formula {
  font-size: 12px
}

#luckysheet-search-formula .inpbox {
  margin-bottom: 5px
}

#luckysheet-search-formula .inpbox label {
  display: block;
  margin-bottom: 5px
}

#luckysheet-search-formula .inpbox input {
  width: 100%;
  height: 24px;
  line-height: 24px;
  border: 1px solid #d4d4d4;
  padding: 0 10px;
  box-sizing: border-box;
  font-size: 12px
}

#luckysheet-search-formula .selbox {
  margin-bottom: 5px
}

#luckysheet-search-formula .selbox select {
  width: 50%;
  height: 24px;
  line-height: 24px;
  border: 1px solid #d4d4d4;
  box-sizing: border-box;
  font-size: 12px
}

#luckysheet-search-formula .listbox label {
  display: block;
  margin-bottom: 5px
}

#formulaTypeList {
  width: 300px;
  height: 170px;
  border: 1px solid #d4d4d4;
  overflow-y: scroll
}

#formulaTypeList .listBox {
  padding: 5px;
  border-bottom: 1px solid #d4d4d4
}

#formulaTypeList .listBox.on {
  background-color: #8c89fe;
  color: #fff
}

#formulaTypeList .listBox span:nth-of-type(1) {
  display: block
}

#formulaTypeList .listBox span:nth-of-type(2) {
  display: block
}

#luckysheet-search-formula-parm {
  width: 502px;
  font-size: 12px
}

#luckysheet-search-formula-parm .parmListBox {
  width: 500px;
  padding: 5px 0;
  border: 1px solid #d4d4d4
}

#luckysheet-search-formula-parm .parmBox {
  height: 30px;
  line-height: 30px;
  margin-bottom: 5px
}

#luckysheet-search-formula-parm .parmBox:last-child {
  margin-bottom: 0
}

#luckysheet-search-formula-parm .parmBox .name {
  width: 90px;
  height: 30px;
  padding: 0 5px;
  float: left;
  text-align: right;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap
}

#luckysheet-search-formula-parm .parmBox .txt {
  width: 198px;
  height: 28px;
  border: 1px solid #d4d4d4;
  float: left
}

#luckysheet-search-formula-parm .parmBox .txt input {
  width: 150px;
  height: 28px;
  padding: 0 10px;
  border: none;
  outline-style: none;
  float: left
}

#luckysheet-search-formula-parm .parmBox .txt i {
  float: right;
  margin-top: 8px;
  margin-right: 5px
}

#luckysheet-search-formula-parm .fa-table {
  cursor: pointer;
  color: #6598f3
}

#luckysheet-search-formula-parm .fa-table:hover {
  color: #ff7e7e
}

#luckysheet-search-formula-parm .parmBox .val {
  width: 190px;
  height: 30px;
  line-height: 30px;
  padding: 0 5px;
  float: left;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap
}

#luckysheet-search-formula-parm .formulaDetails {
  padding: 5px
}

#luckysheet-search-formula-parm .parmDetailsBox {
  max-height: 100px;
  padding: 5px 0 5px 20px;
  overflow-y: scroll
}

#luckysheet-search-formula-parm .parmDetailsBox span {
  display: inline-block
}

#luckysheet-search-formula-parm .result {
  padding: 5px;
  border-top: 1px solid #d4d4d4
}

#textCellColor {
  border: 1px solid #d4d4d4;
  padding: 5px 10px
}

#textCellColor .colorbox {
  height: 30px;
  line-height: 30px;
  margin-bottom: 10px
}

#textCellColor .colorbox input[type=checkbox] {
  float: left;
  margin-top: 10px
}

#textCellColor .colorbox label {
  display: inline-block;
  width: 80px
}

#luckysheet-multiRange-dialog input,#luckysheet-singleRange-dialog input {
  border: 1px solid #d4d4d4;
  padding: 0 10px;
  height: 30px
}

#luckysheet-conditionformat-dialog {
  font-size: 12px
}

#luckysheet-conditionformat-dialog .box .boxTitleOne {
  margin: 5px 0;
  font-weight: 600
}

#luckysheet-conditionformat-dialog .box .inpbox {
  width: 198px;
  height: 28px;
  border: 1px solid #d4d4d4
}

#luckysheet-conditionformat-dialog .box .inpbox input {
  width: 150px;
  height: 28px;
  padding: 0 10px;
  border: none;
  outline-style: none;
  float: left
}

#luckysheet-conditionformat-dialog .box .inpbox2 {
  float: left;
  width: 108px;
  height: 28px;
  border: 1px solid #d4d4d4
}

#luckysheet-conditionformat-dialog .box .inpbox2 input {
  width: 60px;
  height: 28px;
  padding: 0 10px;
  border: none;
  outline-style: none;
  float: left
}

#luckysheet-conditionformat-dialog .box i.fa-table {
  float: right;
  margin-top: 8px;
  margin-right: 5px
}

#luckysheet-conditionformat-dialog .box .fa-table {
  cursor: pointer;
  color: #6598f3
}

#luckysheet-conditionformat-dialog .box .fa-table:hover {
  color: #ff7e7e
}

#luckysheet-conditionformat-dialog .box #daterange-btn {
  width: 188px;
  height: 28px;
  padding: 0 5px;
  line-height: 28px;
  border: 1px solid #d4d4d4;
  cursor: pointer
}

#luckysheet-conditionformat-dialog .box .selectbox {
  width: 150px;
  height: 30px
}

#luckysheet-icon-dataBar-menuButton .bgImgBox {
  width: 28px;
  height: 26px;
  background: url(../plugins/images/CFdataBar.png) no-repeat
}

#luckysheet-icon-colorGradation-menuButton .bgImgBox {
  width: 28px;
  height: 26px;
  background: url(../plugins/images/CFcolorGradation.png) no-repeat
}

#luckysheet-administerRule-dialog {
  font-size: 12px
}

#luckysheet-administerRule-dialog .chooseSheet {
  height: 24px;
  line-height: 24px;
  margin-bottom: 5px
}

#luckysheet-administerRule-dialog .chooseSheet select {
  height: 24px;
  padding: 0 5px;
  box-sizing: border-box;
  font-size: 12px
}

#luckysheet-administerRule-dialog .ruleBox {
  border: 1px solid #d4d4d4
}

#luckysheet-administerRule-dialog .ruleBox .ruleBtn {
  padding: 2.5px 5px;
  border-bottom: 1px solid #d4d4d4
}

#luckysheet-administerRule-dialog .ruleBox .ruleBtn button {
  margin-right: 10px;
  font-size: 12px
}

#luckysheet-administerRule-dialog .ruleBox .ruleList .listTitle {
  height: 30px;
  padding: 0 10px;
  border-bottom: 1px solid #d4d4d4
}

#luckysheet-administerRule-dialog .ruleBox .ruleList .listTitle span {
  display: block;
  height: 100%;
  line-height: 29px;
  float: left
}

#luckysheet-administerRule-dialog .ruleBox .ruleList .listTitle span:nth-of-type(1) {
  width: 30%
}

#luckysheet-administerRule-dialog .ruleBox .ruleList .listTitle span:nth-of-type(2) {
  width: 20%
}

#luckysheet-administerRule-dialog .ruleBox .ruleList .listTitle span:nth-of-type(3) {
  width: 45%
}

#luckysheet-administerRule-dialog .ruleBox .ruleList .listBox {
  height: 150px;
  overflow-y: scroll
}

#luckysheet-administerRule-dialog .ruleBox .ruleList .listBox .item {
  height: 24px;
  padding: 2.5px 10px;
  border-bottom: 1px solid #d4d4d4
}

#luckysheet-administerRule-dialog .ruleBox .ruleList .listBox .item.on {
  background-color: #8c89fe
}

#luckysheet-administerRule-dialog .ruleBox .ruleList .listBox .item .ruleName {
  width: 30%;
  height: 100%;
  line-height: 24px;
  padding-right: 10px;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  float: left;
  box-sizing: border-box
}

#luckysheet-administerRule-dialog .ruleBox .ruleList .listBox .item.on .ruleName {
  color: #fff
}

#luckysheet-administerRule-dialog .ruleBox .ruleList .listBox .item .format {
  width: 20%;
  height: 100%;
  line-height: 24px;
  float: left;
  position: relative
}

#luckysheet-administerRule-dialog .ruleBox .ruleList .listBox .item .format .colorbox {
  display: inline-block;
  width: 16px;
  height: 16px;
  border: solid 1px #d0d0d0;
  margin: 3px 5px;
  cursor: pointer
}

#luckysheet-administerRule-dialog .ruleBox .ruleList .listBox .item .ruleRange {
  width: 45%;
  height: 100%;
  border: 1px solid #d4d4d4;
  float: left;
  margin-left: 10px;
  box-sizing: border-box;
  background-color: #fff
}

#luckysheet-administerRule-dialog .ruleBox .ruleList .listBox .item .ruleRange input {
  width: 130px;
  height: 22px;
  padding: 0 5px;
  border: none;
  outline-style: none;
  float: left
}

#luckysheet-administerRule-dialog .ruleBox .ruleList .listBox .item .ruleRange i.fa-table {
  float: right;
  cursor: pointer;
  color: #6598f3;
  margin-top: 6px;
  margin-right: 5px
}

#luckysheet-administerRule-dialog .ruleBox .ruleList .listBox .item .ruleRange i.fa-table:hover {
  color: #ff7e7e
}

.luckysheet-newEditorRule-dialog {
  font-size: 12px
}

.luckysheet-newEditorRule-dialog .boxTitle {
  margin-bottom: 5px
}

.luckysheet-newEditorRule-dialog .ruleTypeBox {
  border: 1px solid #d4d4d4;
  margin-bottom: 10px
}

.luckysheet-newEditorRule-dialog .ruleTypeBox .ruleTypeItem {
  padding: 3px 5px;
  cursor: pointer
}

.luckysheet-newEditorRule-dialog .ruleTypeBox .ruleTypeItem.on {
  background-color: #7c79fe;
  color: #fff
}

.luckysheet-newEditorRule-dialog .ruleTypeBox .ruleTypeItem .icon {
  font-family: Arial,Helvetica,sans-serif
}

.luckysheet-newEditorRule-dialog .ruleExplainBox {
  border: 1px solid #d4d4d4;
  padding: 10px
}

.luckysheet-newEditorRule-dialog .ruleExplainBox .title {
  display: block;
  font-weight: 600;
  margin-bottom: 5px
}

.luckysheet-newEditorRule-dialog .ruleExplainBox select {
  height: 30px;
  font-size: 12px;
  float: left;
  margin-right: 5px
}

.luckysheet-newEditorRule-dialog .ruleExplainBox .inpbox {
  width: 100px;
  height: 30px;
  border: 1px solid #d4d4d4;
  box-sizing: border-box;
  font-size: 12px;
  float: left
}

.luckysheet-newEditorRule-dialog .ruleExplainBox .inpbox input {
  width: 70px;
  height: 100%;
  border: none;
  outline-style: none;
  padding: 0 5px
}

.luckysheet-newEditorRule-dialog .ruleExplainBox .txt {
  display: block;
  height: 100%;
  line-height: 30px;
  float: left;
  margin: 0 5px
}

.luckysheet-newEditorRule-dialog .ruleExplainBox #isPercent {
  float: left;
  margin: 9px 0 8px 10px
}

.luckysheet-newEditorRule-dialog i.fa-table {
  float: right;
  margin-top: 8px;
  margin-right: 5px
}

.luckysheet-newEditorRule-dialog .fa-table {
  cursor: pointer;
  color: #6598f3
}

.luckysheet-newEditorRule-dialog .fa-table:hover {
  color: #ff7e7e
}

.luckysheet-newEditorRule-dialog .iconsBox {
  height: 30px;
  margin-bottom: 5px;
  position: relative
}

.luckysheet-newEditorRule-dialog .iconsBox label {
  display: block;
  width: 80px;
  height: 30px;
  line-height: 30px;
  float: left
}

.luckysheet-newEditorRule-dialog .iconsBox .showbox {
  width: 150px;
  height: 20px;
  padding: 4px 4px 4px 10px;
  border: 1px solid #e5e5e5;
  background-color: #f5f5f5;
  float: left;
  cursor: pointer
}

.luckysheet-newEditorRule-dialog .iconsBox .showbox .model {
  width: 125px;
  height: 20px;
  background: url(../plugins/images/CFicons.png) no-repeat;
  background-size: 256px;
  float: left
}

.luckysheet-newEditorRule-dialog .iconsBox ul {
  display: none;
  width: 164px;
  max-height: 150px;
  overflow-y: auto;
  background-color: #fff;
  border: 1px solid #e5e5e5;
  position: absolute;
  left: 80px;
  top: 30px;
  list-style: none;
  margin: 0;
  padding: 0
}

.luckysheet-newEditorRule-dialog .iconsBox ul li {
  padding: 5px 10px;
  background-color: #fff;
  cursor: pointer
}

.luckysheet-newEditorRule-dialog .iconsBox ul li:hover {
  background-color: #dfdfdf
}

.luckysheet-newEditorRule-dialog .iconsBox ul li div {
  width: 125px;
  height: 20px;
  background: url(../plugins/images/CFicons.png) no-repeat;
  background-size: 256px
}

#luckysheet-CFicons-dialog .box {
  padding: 10px;
  border: 1px solid #dfdfdf;
  font-size: 14px
}

#luckysheet-CFicons-dialog .box .title {
  height: 20px;
  line-height: 20px;
  padding: 0 10px;
  background-color: #ebebeb
}

#luckysheet-CFicons-dialog .box .list {
  width: 300px;
  padding: 5px 0
}

#luckysheet-CFicons-dialog .box .list .left {
  width: 50%;
  float: left
}

#luckysheet-CFicons-dialog .box .list .right {
  width: 50%;
  float: right
}

#luckysheet-CFicons-dialog .box .list .item {
  width: 125px;
  height: 20px;
  padding: 2.5px 10px;
  background-color: #fff;
  cursor: pointer
}

#luckysheet-CFicons-dialog .box .list .item:hover {
  background-color: #dfdfdf
}

#luckysheet-CFicons-dialog .box .list .item div {
  width: 125px;
  height: 20px;
  background: url(../plugins/images/CFicons.png) no-repeat;
  background-size: 256px
}

#luckysheet-modal-dialog-slider-alternateformat {
  width: 280px;
  font-size: 12px
}

#luckysheet-modal-dialog-slider-alternateformat .luckysheet-modal-dialog-slider-content {
  background-color: #fff;
  overflow-y: scroll
}

#luckysheet-modal-dialog-slider-alternateformat .textTitle {
  padding: 5px 10px;
  font-weight: 600
}

#luckysheet-alternateformat-range {
  width: 198px;
  height: 28px;
  border: 1px solid #d4d4d4;
  margin-left: 10px
}

#luckysheet-alternateformat-range input {
  width: 150px;
  height: 28px;
  padding: 0 10px;
  border: none;
  outline-style: none;
  float: left
}

#luckysheet-alternateformat-range .fa-table {
  float: right;
  margin-top: 8px;
  margin-right: 5px;
  cursor: pointer;
  color: #6598f3
}

#luckysheet-alternateformat-range .fa-table:hover {
  color: #ff7e7e
}

#luckysheet-alternateformat-checkbox {
  padding: 5px 10px;
  border-top: 1px solid #d4d4d4;
  border-bottom: 1px solid #d4d4d4;
  margin: 10px 0
}

#luckysheet-alternateformat-checkbox div {
  height: 20px;
  line-height: 20px
}

#luckysheet-alternateformat-checkbox div:first-child {
  margin-bottom: 5px
}

#luckysheet-alternateformat-checkbox input[type=checkbox] {
  float: left;
  cursor: pointer;
  margin-top: 4px
}

#luckysheet-alternateformat-modelList {
  padding: 0 10px;
  margin-bottom: 10px
}

#luckysheet-alternateformat-modelCustom {
  padding: 0 10px;
  margin-bottom: 10px
}

#luckysheet-modal-dialog-slider-alternateformat .modelbox {
  display: inline-block;
  width: 36px;
  padding: 2px;
  border: 2px solid #fff;
  box-sizing: border-box;
  margin-right: 4px;
  margin-bottom: 4px;
  cursor: pointer
}

#luckysheet-modal-dialog-slider-alternateformat .modelbox.on {
  border-color: #726efe
}

#luckysheet-modal-dialog-slider-alternateformat .modelbox .box {
  width: 100%;
  border: 1px solid #d4d4d4;
  box-sizing: border-box
}

#luckysheet-modal-dialog-slider-alternateformat .modelbox .box span {
  display: block;
  width: 100%;
  height: 10px;
  line-height: 9px;
  text-align: center;
  border-bottom: 1px solid #d4d4d4;
  box-sizing: border-box
}

#luckysheet-modal-dialog-slider-alternateformat .modelbox .box span:last-child {
  line-height: 10px;
  border-bottom: none
}

#luckysheet-alternateformat-modelToning {
  padding: 10px
}

#luckysheet-alternateformat-modelToning .toningbox {
  height: 25px;
  margin-bottom: 5px
}

#luckysheet-alternateformat-modelToning .toningbox .toningShow {
  width: 150px;
  height: 100%;
  line-height: 23px;
  text-align: center;
  border: 1px solid #d4d4d4;
  float: left;
  margin-right: 10px
}

#luckysheet-alternateformat-modelToning .toningbox .luckysheet-color-menu-button-indicator {
  width: 20px;
  float: left;
  user-select: none;
  cursor: pointer
}

#luckysheet-alternateformat-modelToning .toningbox .luckysheet-color-menu-button-indicator .luckysheet-icon {
  user-select: none;
  margin-bottom: -6px
}

#luckysheet-alternateformat-colorSelect-dialog .currenColor {
  font-size: 12px;
  margin-bottom: 5px
}

#luckysheet-alternateformat-colorSelect-dialog .currenColor span {
  display: inline-block;
  width: 16px;
  height: 16px;
  border: solid 1px #d0d0d0;
  margin-left: 5px;
  margin-bottom: -5px;
  cursor: pointer
}

#luckysheet-alternateformat-rangeDialog input {
  border: 1px solid #d4d4d4;
  padding: 0 10px;
  height: 30px
}

#luckysheet-ifFormulaGenerator-dialog {
  font-size: 12px
}

#luckysheet-ifFormulaGenerator-dialog .ifAttr .attrBox {
  height: 30px;
  margin-bottom: 10px
}

#luckysheet-ifFormulaGenerator-dialog .ifAttr .attrBox label {
  display: block;
  width: 100px;
  height: 100%;
  line-height: 30px;
  padding: 0 5px;
  text-align: right;
  float: left
}

#luckysheet-ifFormulaGenerator-dialog .ifAttr .attrBox .inpBox {
  width: 150px;
  height: 100%;
  padding: 0 10px;
  border: 1px solid #d4d4d4;
  box-sizing: border-box;
  float: left
}

#luckysheet-ifFormulaGenerator-dialog .ifAttr .attrBox .inpBox input {
  width: 100px;
  height: 100%;
  padding: 0;
  border: none;
  outline-style: none;
  background: 0 0;
  float: left
}

#luckysheet-ifFormulaGenerator-dialog .ifAttr .attrBox .inpBox i.fa-table {
  font-size: 14px;
  color: #6598f3;
  float: right;
  margin-right: 0;
  margin-top: 8px;
  cursor: pointer
}

#luckysheet-ifFormulaGenerator-dialog .ifAttr .attrBox .inpBox i.fa-table:hover {
  color: #ff7e7e
}

#luckysheet-ifFormulaGenerator-dialog .ifAttr .attrBox span.text {
  height: 100%;
  line-height: 30px;
  padding: 0 5px;
  float: left
}

#luckysheet-ifFormulaGenerator-dialog #largeRange,#luckysheet-ifFormulaGenerator-dialog #smallRange {
  width: 100px;
  height: 100%;
  padding: 0 10px;
  border: 1px solid #d4d4d4;
  box-sizing: border-box;
  float: left
}

#luckysheet-ifFormulaGenerator-dialog #rangeAssess {
  height: 100%;
  line-height: 30px;
  float: left;
  margin-left: 20px
}

#luckysheet-ifFormulaGenerator-dialog #rangeAssess i.fa-table {
  color: #6598f3;
  cursor: pointer
}

#luckysheet-ifFormulaGenerator-dialog #rangeAssess i.fa-table:hover {
  color: #ff7e7e
}

#luckysheet-ifFormulaGenerator-dialog #DivisionMethod {
  width: 100px;
  height: 100%;
  border: 1px solid #d4d4d4;
  box-sizing: border-box;
  float: left
}

#luckysheet-ifFormulaGenerator-dialog #DivisionMethodVal {
  width: 120px;
  height: 100%;
  border: 1px solid #d4d4d4;
  padding: 0 10px;
  box-sizing: border-box;
  float: left;
  margin-left: 10px
}

#luckysheet-ifFormulaGenerator-dialog #createBtn {
  width: 100px;
  height: 100%;
  line-height: 30px;
  border-radius: 5px;
  text-align: center;
  font-size: 14px;
  color: #fff;
  background-color: #8c89fe;
  float: right;
  cursor: pointer
}

#luckysheet-ifFormulaGenerator-dialog .ifList {
  border-top: 1px solid #d4d4d4;
  height: 180px;
  padding: 10px;
  overflow-y: scroll
}

#luckysheet-ifFormulaGenerator-dialog .ifList .item {
  height: 30px;
  margin-bottom: 10px
}

#luckysheet-ifFormulaGenerator-dialog .ifList .item input {
  width: 80px;
  height: 100%;
  border: 1px solid #d4d4d4;
  padding: 0 5px;
  background: 0 0;
  box-sizing: border-box;
  float: left
}

#luckysheet-ifFormulaGenerator-dialog .ifList .item input.markText {
  width: 140px
}

#luckysheet-ifFormulaGenerator-dialog .ifList .item select {
  width: 50px;
  height: 100%;
  padding: 0 5px;
  border: 1px solid #d4d4d4;
  box-sizing: border-box;
  float: left;
  margin: 0 10px
}

#luckysheet-ifFormulaGenerator-dialog .ifList .item span {
  height: 100%;
  line-height: 30px;
  float: left;
  margin: 0 10px
}

#luckysheet-ifFormulaGenerator-dialog .ifList .item i.fa-remove {
  font-size: 16px;
  float: left;
  margin-left: 15px;
  margin-top: 7px;
  color: #d6d6d6;
  cursor: pointer
}

#luckysheet-ifFormulaGenerator-dialog .ifList .item i.fa-remove:hover {
  color: #333
}

#luckysheet-ifFormulaGenerator-multiRange-dialog input,#luckysheet-ifFormulaGenerator-singleRange-dialog input {
  border: 1px solid #d4d4d4;
  padding: 0 10px;
  height: 30px
}

.pictorialBarUploadImg:hover {
  border: 1px solid #ccc!important;
  background: #efefef
}

#luckysheet-dropCell-icon #icon_dropCell {
  width: 25px;
  height: 15px;
  background-image: url(../plugins/images/icon_dropCell.png);
  background-repeat: no-repeat;
  background-position: center;
  background-size: 100% 100%
}

#luckysheet-locationCell-dialog .listbox {
  border: 1px solid #dfdfdf;
  padding: 10px;
  font-size: 14px;
  color: #000
}

#luckysheet-locationCell-dialog .listbox .listItem {
  padding: 5px 0
}

#luckysheet-locationCell-dialog .listbox .listItem input[type=radio] {
  float: left;
  margin-top: 5px
}

#luckysheet-locationCell-dialog .listbox .listItem .subbox {
  height: 30px;
  padding: 0 10px
}

#luckysheet-locationCell-dialog .listbox .listItem .subbox .subItem {
  float: left;
  margin-right: 5px
}

#luckysheet-moreFormat-dialog {
  font-size: 14px;
  color: #000
}

#luckysheet-moreFormat-dialog .decimal {
  margin-bottom: 5px;
  height: 30px;
  line-height: 30px
}

#luckysheet-moreFormat-dialog .decimal input {
  width: 80px;
  height: 24px;
  padding: 0 5px
}

#luckysheet-moreFormat-dialog .listbox {
  border: 1px solid #666;
  height: 240px;
  overflow-y: auto
}

#luckysheet-moreFormat-dialog .listbox .listItem {
  height: 30px;
  padding: 0 20px 0 10px;
  border-bottom: 1px solid #dfdfdf
}

#luckysheet-moreFormat-dialog .listbox .listItem.on {
  background-color: #7c79fe;
  color: #fff
}

#luckysheet-moreFormat-dialog .listbox .listItem .name {
  line-height: 29px;
  float: left
}

#luckysheet-moreFormat-dialog .listbox .listItem .value {
  line-height: 30px;
  float: right;
  color: gray
}

#luckysheet-moreFormat-dialog .listbox .listItem.on .value {
  color: #fff
}

#luckysheet-splitColumn-dialog {
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none
}

#luckysheet-splitColumn-dialog .box {
  font-size: 14px
}

#luckysheet-splitColumn-dialog .box .boxTitle {
  padding: 5px
}

#luckysheet-splitColumn-dialog .box .boxMain {
  padding: 5px;
  border: 1px solid #dfdfdf
}

#luckysheet-splitColumn-dialog .box input[type=checkbox] {
  float: left;
  margin-top: 5px
}

#luckysheet-splitColumn-dialog .box .boxMain input[type=text] {
  margin-left: 5px;
  width: 50px;
  padding: 0 5px
}

#luckysheet-splitColumn-dialog .box #splitColumnData {
  height: 100px;
  overflow-y: auto
}

#luckysheet-splitColumn-dialog .box #splitColumnData table {
  border-collapse: collapse
}

#luckysheet-splitColumn-dialog .box #splitColumnData td {
  border: 1px solid #333
}

.luckysheet-datavisual-config .luckysheet-datavisual-accordion-content:last-child {
  padding-bottom: 100px
}

.luckysheet-postil-dialog-move {
  position: absolute;
  margin: 0;
  padding: 0;
  top: 0;
  left: 0;
  bottom: 0;
  right: 0;
  pointer-events: none
}

.luckysheet-postil-dialog-move .luckysheet-postil-dialog-move-item {
  position: absolute;
  pointer-events: all;
  cursor: move
}

.luckysheet-postil-dialog-move .luckysheet-postil-dialog-move-item-t {
  width: 100%;
  height: 3px;
  border-bottom: 1px solid #000;
  left: 0;
  top: -4px
}

.luckysheet-postil-dialog-move .luckysheet-postil-dialog-move-item-r {
  width: 3px;
  height: 100%;
  border-left: 1px solid #000;
  right: -4px;
  top: 0
}

.luckysheet-postil-dialog-move .luckysheet-postil-dialog-move-item-b {
  width: 100%;
  height: 3px;
  border-top: 1px solid #000;
  left: 0;
  bottom: -4px
}

.luckysheet-postil-dialog-move .luckysheet-postil-dialog-move-item-l {
  width: 3px;
  height: 100%;
  border-right: 1px solid #000;
  left: -4px;
  top: 0
}

.luckysheet-postil-show-active .luckysheet-postil-dialog-move .luckysheet-postil-dialog-move-item {
  border-color: #0188fb
}

.luckysheet-postil-dialog-resize {
  position: absolute;
  margin: 0;
  padding: 0;
  top: -2px;
  left: -2px;
  bottom: -2px;
  right: -2px;
  pointer-events: none
}

.luckysheet-postil-dialog-resize .luckysheet-postil-dialog-resize-item {
  position: absolute;
  height: 6px;
  width: 6px;
  border: 1px solid #0188fb;
  pointer-events: all
}

.luckysheet-postil-dialog-resize .luckysheet-postil-dialog-resize-item-lt {
  left: -6px;
  top: -6px;
  cursor: se-resize
}

.luckysheet-postil-dialog-resize .luckysheet-postil-dialog-resize-item-mt {
  left: 50%;
  top: -6px;
  margin-left: -4px;
  cursor: s-resize
}

.luckysheet-postil-dialog-resize .luckysheet-postil-dialog-resize-item-lm {
  top: 50%;
  left: -6px;
  margin-top: -4px;
  cursor: w-resize
}

.luckysheet-postil-dialog-resize .luckysheet-postil-dialog-resize-item-rm {
  top: 50%;
  right: -6px;
  margin-top: -4px;
  cursor: w-resize
}

.luckysheet-postil-dialog-resize .luckysheet-postil-dialog-resize-item-rt {
  right: -6px;
  top: -6px;
  cursor: ne-resize
}

.luckysheet-postil-dialog-resize .luckysheet-postil-dialog-resize-item-lb {
  left: -6px;
  bottom: -6px;
  cursor: ne-resize
}

.luckysheet-postil-dialog-resize .luckysheet-postil-dialog-resize-item-mb {
  left: 50%;
  bottom: -6px;
  margin-left: -4px;
  cursor: s-resize
}

.luckysheet-postil-dialog-resize .luckysheet-postil-dialog-resize-item-rb {
  right: -6px;
  bottom: -6px;
  cursor: se-resize
}

.luckysheet-datavisual-config .luckysheet-datavisual-accordion-content:last-child {
  padding-bottom: 100px
}

.luckysheet-datavisual-left .el-tabs__content {
  overflow: auto
}

#luckysheet-modal-dialog-activeImage .luckysheet-modal-dialog-content {
  width: 100%;
  height: 100%;
  position: absolute;
  left: 0;
  top: 0;
  cursor: move;
  image-rendering: -moz-crisp-edges;
  image-rendering: -o-crisp-edges;
  image-rendering: -webkit-optimize-contrast;
  image-rendering: crisp-edges
}

#luckysheet-modal-dialog-cropping::before {
  content: "";
  outline: 1px solid #fff;
  position: absolute;
  left: 33.3%;
  right: 33.3%;
  top: 0;
  bottom: 0;
  z-index: 1;
  pointer-events: none
}

#luckysheet-modal-dialog-cropping::after {
  content: "";
  outline: 1px solid #fff;
  position: absolute;
  left: 0;
  right: 0;
  top: 33.3%;
  bottom: 33.3%;
  z-index: 1;
  pointer-events: none
}

#luckysheet-modal-dialog-cropping .cropping-mask {
  filter: brightness(.5);
  position: absolute;
  background-size: 100% 100%;
  left: 0;
  top: 0
}

#luckysheet-modal-dialog-cropping .cropping-content {
  position: absolute;
  overflow: hidden;
  background-position: 0 0;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%
}

#luckysheet-modal-dialog-cropping .luckysheet-modal-dialog-resize {
  border: none;
  position: absolute;
  margin: 0;
  padding: 0;
  top: 0;
  left: 0;
  bottom: 0;
  right: 0;
  pointer-events: all
}

#luckysheet-modal-dialog-cropping .resize-item {
  width: 0;
  height: 0;
  background: 0 0;
  border: none;
  position: absolute;
  z-index: 3
}

#luckysheet-modal-dialog-cropping .resize-item::before {
  content: "";
  display: block;
  position: absolute;
  background: #000
}

#luckysheet-modal-dialog-cropping .resize-item::after {
  content: "";
  display: block;
  position: absolute;
  background: #000
}

#luckysheet-modal-dialog-cropping .lt {
  left: 0;
  top: 0;
  cursor: nwse-resize
}

#luckysheet-modal-dialog-cropping .lt::before {
  width: 18px;
  height: 4px;
  left: 0;
  top: 0;
  border-right: 2px solid #fff;
  border-bottom: 2px solid #fff
}

#luckysheet-modal-dialog-cropping .lt::after {
  width: 4px;
  height: 14px;
  left: 0;
  top: 4px;
  border-right: 2px solid #fff;
  border-bottom: 2px solid #fff
}

#luckysheet-modal-dialog-cropping .mt {
  left: 50%;
  top: 0;
  cursor: ns-resize
}

#luckysheet-modal-dialog-cropping .mt::before {
  width: 18px;
  height: 4px;
  left: -11px;
  top: 0;
  border-left: 2px solid #fff;
  border-right: 2px solid #fff;
  border-bottom: 2px solid #fff
}

#luckysheet-modal-dialog-cropping .rt {
  right: 0;
  top: 0;
  cursor: nesw-resize
}

#luckysheet-modal-dialog-cropping .rt::before {
  width: 18px;
  height: 4px;
  right: 0;
  top: 0;
  border-left: 2px solid #fff;
  border-bottom: 2px solid #fff
}

#luckysheet-modal-dialog-cropping .rt::after {
  width: 4px;
  height: 14px;
  right: 0;
  top: 4px;
  border-left: 2px solid #fff;
  border-bottom: 2px solid #fff
}

#luckysheet-modal-dialog-cropping .lm {
  left: 0;
  top: 50%;
  cursor: ew-resize
}

#luckysheet-modal-dialog-cropping .lm::before {
  width: 4px;
  height: 18px;
  left: 0;
  top: -11px;
  border-right: 2px solid #fff;
  border-top: 2px solid #fff;
  border-bottom: 2px solid #fff
}

#luckysheet-modal-dialog-cropping .rm {
  right: 0;
  top: 50%;
  cursor: ew-resize
}

#luckysheet-modal-dialog-cropping .rm::before {
  width: 4px;
  height: 18px;
  right: 0;
  top: -11px;
  border-left: 2px solid #fff;
  border-top: 2px solid #fff;
  border-bottom: 2px solid #fff
}

#luckysheet-modal-dialog-cropping .lb {
  left: 0;
  bottom: 0;
  cursor: nesw-resize
}

#luckysheet-modal-dialog-cropping .lb::before {
  width: 18px;
  height: 4px;
  left: 0;
  bottom: 0;
  border-right: 2px solid #fff;
  border-top: 2px solid #fff
}

#luckysheet-modal-dialog-cropping .lb::after {
  width: 4px;
  height: 14px;
  left: 0;
  bottom: 4px;
  border-right: 2px solid #fff;
  border-top: 2px solid #fff
}

#luckysheet-modal-dialog-cropping .rb {
  right: 0;
  bottom: 0;
  cursor: nwse-resize
}

#luckysheet-modal-dialog-cropping .rb::before {
  width: 18px;
  height: 4px;
  right: 0;
  bottom: 0;
  border-left: 2px solid #fff;
  border-top: 2px solid #fff
}

#luckysheet-modal-dialog-cropping .rb::after {
  width: 4px;
  height: 14px;
  right: 0;
  bottom: 4px;
  border-left: 2px solid #fff;
  border-top: 2px solid #fff
}

#luckysheet-modal-dialog-cropping .mb {
  left: 50%;
  bottom: 0;
  cursor: ns-resize
}

#luckysheet-modal-dialog-cropping .mb::before {
  width: 18px;
  height: 4px;
  left: -11px;
  bottom: 0;
  border-left: 2px solid #fff;
  border-right: 2px solid #fff;
  border-top: 2px solid #fff
}

#luckysheet-modal-dialog-slider-imageCtrl .luckysheet-modal-dialog-slider-content {
  background-color: #fff
}

#luckysheet-modal-dialog-slider-imageCtrl .slider-box {
  border-bottom: 1px solid #e1e4e8
}

#luckysheet-modal-dialog-slider-imageCtrl .slider-box .slider-box-title {
  padding: 10px 20px;
  font-weight: 600
}

#luckysheet-modal-dialog-slider-imageCtrl .slider-box .slider-box-radios {
  padding: 10px 30px
}

#luckysheet-modal-dialog-slider-imageCtrl .slider-box .radio-item {
  margin-bottom: 10px
}

#luckysheet-modal-dialog-slider-imageCtrl .slider-box .radio-item:last-child {
  margin-bottom: 0
}

#luckysheet-modal-dialog-slider-imageCtrl .slider-box .radio-item input {
  vertical-align: sub
}

#luckysheet-modal-dialog-slider-imageCtrl .slider-box .slider-box-checkbox {
  padding: 10px 30px;
  border-top: 1px solid #e1e4e8
}

#luckysheet-modal-dialog-slider-imageCtrl .slider-box .slider-box-checkbox input {
  vertical-align: middle
}

#luckysheet-modal-dialog-slider-imageCtrl .slider-box .slider-box-borderConfig {
  padding: 10px 30px
}

#luckysheet-modal-dialog-slider-imageCtrl .slider-box .border-item {
  margin-bottom: 10px
}

#luckysheet-modal-dialog-slider-imageCtrl .slider-box .border-item:last-child {
  margin-bottom: 0
}

#luckysheet-modal-dialog-slider-imageCtrl .slider-box .border-item label {
  display: inline-block;
  width: 40px
}

#luckysheet-modal-dialog-slider-imageCtrl .slider-box .border-item input {
  width: 130px;
  padding: 5px
}

#luckysheet-modal-dialog-slider-imageCtrl .slider-box .border-item .imgItemBorderColor {
  display: inline-block;
  width: 20px;
  height: 20px;
  padding: 2px;
  border: 1px solid #e1e4e8;
  vertical-align: middle;
  cursor: pointer
}

#luckysheet-modal-dialog-slider-imageCtrl .slider-box .border-item .imgItemBorderColor span {
  display: block;
  width: 100%;
  height: 100%
}

#luckysheet-imageCtrl-colorSelect-dialog .currenColor {
  font-size: 12px;
  margin-bottom: 5px
}

#luckysheet-imageCtrl-colorSelect-dialog .currenColor span {
  display: inline-block;
  width: 16px;
  height: 16px;
  border: solid 1px #d0d0d0;
  margin-left: 5px;
  margin-bottom: -5px;
  cursor: pointer
}

#luckysheet-modal-dialog-activeImage,#luckysheet-modal-dialog-cropping {
  background: 0 0;
  box-shadow: none
}

.luckysheet-modal-dialog-image {
  border: none;
  box-shadow: none;
  background: 0 0;
  box-shadow: none;
  image-rendering: -moz-crisp-edges;
  image-rendering: -o-crisp-edges;
  image-rendering: -webkit-optimize-contrast;
  image-rendering: crisp-edges
}

#luckysheet-modal-dialog-activeImage .luckysheet-modal-dialog-content,.luckysheet-modal-dialog-image .luckysheet-modal-dialog-content {
  background: 0 0
}

.cell-date-picker {
  position: absolute;
  display: none
}

#luckysheet-insertLink-dialog {
  user-select: none
}

#luckysheet-insertLink-dialog .box {
  font-size: 12px
}

#luckysheet-insertLink-dialog .box-item {
  height: 30px;
  line-height: 30px;
  margin-bottom: 10px
}

#luckysheet-insertLink-dialog .box-item label {
  display: inline-block;
  width: 80px;
  text-align: right;
  margin-right: 10px
}

#luckysheet-insertLink-dialog .box-item input {
  width: 200px;
  height: 30px;
  padding: 0 10px;
  border: 1px solid #d4d4d4;
  outline-style: none;
  box-sizing: border-box
}

#luckysheet-insertLink-dialog .box-item select {
  width: 200px;
  height: 30px;
  padding: 0 5px;
  border: 1px solid #d4d4d4;
  outline-style: none;
  box-sizing: border-box
}

#luckysheet-dataVerification-dialog {
  user-select: none
}

#luckysheet-dataVerification-dialog .box {
  font-size: 12px
}

#luckysheet-dataVerification-dialog .box select {
  width: 100%;
  height: 30px;
  border-color: #d4d4d4;
  outline-style: none
}

#luckysheet-dataVerification-dialog .box input::-webkit-input-placeholder {
  color: #d4d4d4
}

#luckysheet-dataVerification-dialog .box input:-moz-placeholder {
  color: #d4d4d4
}

#luckysheet-dataVerification-dialog .box input::-moz-placeholder {
  color: #d4d4d4
}

#luckysheet-dataVerification-dialog .box input:-ms-input-placeholder {
  color: #d4d4d4
}

#luckysheet-dataVerification-dialog .box-item {
  padding: 10px;
  border-bottom: 1px solid #e1e4e8
}

#luckysheet-dataVerification-dialog .box-item .box-item-title {
  font-size: 14px;
  font-weight: 600;
  margin-bottom: 10px
}

#luckysheet-dataVerification-dialog .box-item .range {
  width: 100%;
  height: 30px;
  border: 1px solid #d4d4d4
}

#luckysheet-dataVerification-dialog .box-item .range input {
  width: calc(100% - 30px);
  height: 30px;
  padding: 0 10px;
  float: left;
  border: none;
  outline-style: none;
  box-sizing: border-box
}

#luckysheet-dataVerification-dialog .box-item .range i.fa-table {
  float: right;
  margin-top: 9px;
  margin-right: 5px;
  cursor: pointer;
  color: #6598f3
}

#luckysheet-dataVerification-dialog .box-item .show-box {
  margin-top: 10px
}

#luckysheet-dataVerification-dialog .box-item .check-box {
  height: 30px;
  line-height: 30px;
  margin-bottom: 10px
}

#luckysheet-dataVerification-dialog .box-item .check-box:last-child {
  margin-bottom: 0
}

#luckysheet-dataVerification-dialog .box-item .check-box input {
  height: 30px;
  padding: 0 10px;
  border: 1px solid #d4d4d4;
  box-sizing: border-box
}

#luckysheet-dataVerification-dialog .box-item .check {
  line-height: 30px
}

#luckysheet-dataVerification-dialog .box-item .check input {
  vertical-align: text-top
}

#luckysheet-dataVerification-dialog .box-item .input {
  height: 30px;
  line-height: 30px;
  margin-top: 10px
}

#luckysheet-dataVerification-dialog .box-item .input input {
  height: 30px;
  padding: 4px 10px 4px 10px;
  border: 1px solid #d4d4d4;
  box-sizing: border-box
}

#luckysheet-dataVerification-dialog .box-item .input1 input {
  width: 150px
}

#luckysheet-dataVerification-dialog .box-item .input2 input {
  width: 100%
}

#luckysheet-dataVerification-dialog .box-item .input span {
  display: inline-block;
  width: 30px;
  text-align: center
}

#luckysheet-dataVerification-dialog .data-verification-hint-text {
  width: 100%;
  height: 30px;
  border: 1px solid #d4d4d4;
  margin-top: 10px
}

#luckysheet-dataVerification-dialog .data-verification-hint-text input {
  display: block;
  width: 100%;
  height: 100%;
  padding: 0 10px;
  border: none;
  outline-style: none;
  box-sizing: border-box
}

#luckysheet-dataVerification-dialog .show-box .show-box-item {
  display: none
}

#luckysheet-dataVerificationRange-dialog input {
  height: 30px;
  padding: 0 10px;
  border: 1px solid #d4d4d4;
  outline-style: none
}

#luckysheet-dataVerification-dropdown-btn {
  display: none;
  width: 20px;
  height: 20px;
  background-color: #fff;
  position: absolute;
  z-index: 10;
  overflow: hidden
}

#luckysheet-dataVerification-dropdown-btn::after {
  content: '';
  width: 10px;
  height: 10px;
  background: url(arrow-down.png) center no-repeat;
  position: absolute;
  left: 50%;
  top: 50%;
  margin-left: -5px;
  margin-top: -5px
}

#luckysheet-dataVerification-dropdown-List {
  display: none;
  background-color: #fff;
  border: 1px solid #ccc;
  box-shadow: 0 2px 4px rgba(0,0,0,.2);
  position: absolute;
  z-index: 10000;
  box-sizing: border-box
}

#luckysheet-dataVerification-dropdown-List .dropdown-List-item {
  padding: 5px 10px;
  box-sizing: border-box;
  cursor: pointer
}

#luckysheet-dataVerification-dropdown-List .dropdown-List-item:hover {
  background-color: #e1e1e1
}

#luckysheet-dataVerification-showHintBox {
  display: none;
  padding: 10px;
  background-color: #fff;
  border: 1px solid #ccc;
  box-shadow: 0 2px 4px rgba(0,0,0,.2);
  position: absolute;
  z-index: 1000;
  user-select: none;
  cursor: default;
  white-space: nowrap
}

.luckysheet-print-viewList {
  position: relative;
  float: right;
  width: 126px;
  height: 22px;
  line-height: 22px;
  text-align: center;
  white-space: nowrap;
  overflow: hidden;
  display: flex;
  align-items: center;
  user-select: none
}

.luckysheet-print-viewBtn {
  position: absolute;
  top: 0;
  left: 0;
  width: 42px;
  height: 22px;
  align-items: center;
  justify-content: center;
  cursor: pointer
}

.luckysheet-print-viewBtn .iconfont {
  font-size: 22px
}

.luckysheet-print-viewBtn:hover {
  background: #e1e4e8
}

.luckysheet-print-viewBtn-active {
  background: #dcdcdc;
  cursor: default
}

.luckysheet-print-viewBtn-active:hover {
  background: #dcdcdc
}

.luckysheet-print-viewNormal {
  left: 0
}

.luckysheet-print-viewLayout {
  left: 42px
}

.luckysheet-print-viewPage {
  left: 84px
}

#luckysheet-modal-dialog-slider-protection .luckysheet-modal-dialog-slider-content {
  background: #fff
}

.luckysheet-slider-protection-config {
  position: absolute;
  width: 100%
}

.luckysheet-slider-protection-row {
  position: relative;
  width: 98%;
  height: 35px;
  left: 1%
}

.luckysheet-slider-protection-column {
  position: absolute;
  height: 100%
}

.luckysheet-protection-rangeItem-dialog input,.luckysheet-protection-rangeItem-dialog textarea,.luckysheet-protection-sheet-validation input,.luckysheet-slider-protection-config input,.luckysheet-slider-protection-config textarea {
  border: 1px solid #d4d4d4;
  outline: 0
}

.luckysheet-protection-rangeItem-dialog input:focus,.luckysheet-protection-rangeItem-dialog textarea:focus,.luckysheet-protection-sheet-validation input:focus,.luckysheet-slider-protection-config input:focus,.luckysheet-slider-protection-config textarea:focus {
  border: 1px solid #0389fb;
  outline: 0
}

.luckysheet-protection-input {
  width: 100%;
  height: 19px;
  position: relative
}

.luckysheet-protection-textarea {
  width: 100%;
  height: 47px;
  position: relative;
  resize: none
}

.luckysheet-protection-column-2x {
  width: 20%
}

.luckysheet-protection-column-3x {
  width: 30%
}

.luckysheet-protection-column-4x {
  width: 40%
}

.luckysheet-protection-column-5x {
  width: 50%
}

.luckysheet-protection-column-6x {
  width: 60%
}

.luckysheet-protection-column-7x {
  width: 70%
}

.luckysheet-protection-column-8x {
  width: 80%
}

.luckysheet-protection-column-9x {
  width: 90%
}

.luckysheet-protection-column-10x {
  width: 100%
}

.luckysheet-protection-column-left {
  text-align: left
}

.luckysheet-protection-column-center {
  text-align: center
}

.luckysheet-protection-column-right {
  text-align: right
}

.luckysheet-slider-protection-ok {
  position: absolute;
  width: 100%;
  height: 100%;
  background: #0188fb;
  color: #fff;
  text-align: center;
  line-height: 45px;
  font-size: 16px;
  cursor: pointer
}

.luckysheet-slider-protection-ok:hover {
  background: #0181ee
}

.luckysheet-slider-protection-ok:active {
  background: #0074da
}

.luckysheet-slider-protection-cancel {
  position: absolute;
  width: 100%;
  height: 100%;
  background: #e6e6e6;
  color: #353535;
  text-align: center;
  line-height: 45px;
  font-size: 16px;
  cursor: pointer
}

.luckysheet-slider-protection-cancel:hover {
  background: #d6d6d6
}

.luckysheet-slider-protection-cancel:active {
  background: #c7c7c7
}

.luckysheet-slider-protection-addRange {
  line-height: 23px;
  font-size: 12px;
  top: 2px;
  height: 23px
}

.luckysheet-protection-rangeItem {
  position: relative;
  width: 100%;
  height: 30px;
  line-height: 30px;
  font-size: 12px;
  overflow: hidden
}

.luckysheet-protection-rangeItem:hover {
  background: #d5d5d5
}

.luckysheet-protection-rangeItem>div {
  position: absolute;
  height: 100%;
  text-align: center;
  overflow: hidden
}

.luckysheet-protection-rangeItem .luckysheet-protection-rangeItem-del {
  left: 5px;
  top: 5px;
  height: 20px;
  width: 20px;
  font-size: 14px;
  line-height: 20px;
  cursor: pointer
}

.luckysheet-protection-rangeItem .luckysheet-protection-rangeItem-name {
  left: 30px;
  width: 80px;
  text-align: left
}

.luckysheet-protection-rangeItem .luckysheet-protection-rangeItem-range {
  left: 110px;
  width: 120px
}

.luckysheet-protection-rangeItem .luckysheet-protection-rangeItem-update {
  left: 230px;
  width: 30px;
  font-size: 14px;
  top: 5px;
  height: 20px;
  width: 20px;
  line-height: 20px;
  cursor: pointer
}

.luckysheet-protection-rangeItem .luckysheet-protection-rangeItem-del:hover,.luckysheet-protection-rangeItem .luckysheet-protection-rangeItem-update:hover {
  background: #0181ee;
  color: #fff
}

.luckysheet-protection-rangeItem .luckysheet-protection-rangeItem-del:active,.luckysheet-protection-rangeItem .luckysheet-protection-rangeItem-update:active {
  background: #0074da;
  color: #fff
}

.luckysheet-protection-rangeItem-content {
  position: relative;
  width: 350px;
  height: 270px
}

#luckysheet-protection-rangeItem-dialog .luckysheet-slider-protection-column .range {
  width: 100%;
  height: 30px;
  border: 1px solid #d4d4d4
}

#luckysheet-protection-rangeItem-dialog .luckysheet-slider-protection-column .range input {
  width: calc(100% - 30px);
  height: 30px;
  padding: 0 10px;
  float: left;
  border: none;
  outline-style: none;
  box-sizing: border-box
}

#luckysheet-protection-rangeItem-dialog .luckysheet-slider-protection-column .range i.fa-table {
  float: right;
  margin-top: 9px;
  margin-right: 5px;
  cursor: pointer;
  color: #6598f3
}

.luckysheet-protection-rangeItemTextarea {
  width: 100%;
  height: 120px;
  position: relative;
  resize: none
}

.luckysheet-protection-rangeItemiInput {
  width: 100%;
  height: 23px;
  position: relative
}

.luckysheet-protection-sheet-validation {
  width: 390px;
  height: 180px;
  display: none
}

.luckysheet-zoom-content {
  position: relative;
  float: right;
  width: 210px;
  height: 22px;
  line-height: 22px;
  text-align: right;
  padding-right: 10px;
  white-space: nowrap;
  overflow: hidden;
  display: flex;
  align-items: center;
  user-select: none
}

.luckysheet-zoom-content .luckysheet-zoom-minus {
  position: absolute;
  top: 0;
  left: 0;
  width: 20px;
  height: 20px;
  cursor: pointer;
  display: flex;
  align-items: center;
  justify-content: center
}

.luckysheet-zoom-content .luckysheet-zoom-minus-icon {
  background-image: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB3aWR0aD0iMTRweCIgaGVpZ2h0PSIycHgiIHZpZXdCb3g9IjAgMCAxNCAyIiB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiPgogICAgPCEtLSBHZW5lcmF0b3I6IFNrZXRjaCA2MyAoOTI0NDUpIC0gaHR0cHM6Ly9za2V0Y2guY29tIC0tPgogICAgPHRpdGxlPnJpcWlxdWppYW7lpIfku70gNDU8L3RpdGxlPgogICAgPGRlc2M+Q3JlYXRlZCB3aXRoIFNrZXRjaC48L2Rlc2M+CiAgICA8ZyBpZD0iMjAyMC8wOC8xNCIgc3Ryb2tlPSJub25lIiBzdHJva2Utd2lkdGg9IjEiIGZpbGw9Im5vbmUiIGZpbGwtcnVsZT0iZXZlbm9kZCI+CiAgICAgICAgPGcgaWQ9IueUu+adv+Wkh+S7vS0yIiB0cmFuc2Zvcm09InRyYW5zbGF0ZSgtMTcwNC4wMDAwMDAsIC0xMDY0LjAwMDAwMCkiIGZpbGw9IiM0NDRENUEiPgogICAgICAgICAgICA8ZyBpZD0icmlxaXF1amlhbuWkh+S7vS0xMjYiIHRyYW5zZm9ybT0idHJhbnNsYXRlKDE2OTkuMDAwMDAwLCAxMDUzLjAwMDAwMCkiPgogICAgICAgICAgICAgICAgPGcgaWQ9Iue8lue7hCIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoNS4wMDAwMDAsIDExLjAwMDAwMCkiPgogICAgICAgICAgICAgICAgICAgIDxyZWN0IGlkPSLnn6nlvaIiIHg9IjAiIHk9IjAiIHdpZHRoPSIxNCIgaGVpZ2h0PSIyIj48L3JlY3Q+CiAgICAgICAgICAgICAgICA8L2c+CiAgICAgICAgICAgIDwvZz4KICAgICAgICA8L2c+CiAgICA8L2c+Cjwvc3ZnPg==);
  width: 14px;
  height: 2px
}

.luckysheet-zoom-content .luckysheet-zoom-minus:hover {
  background-color: #e1e4e8
}

.luckysheet-zoom-content .luckysheet-zoom-slider {
  position: absolute;
  top: 0;
  left: 25px;
  width: 100px;
  height: 100%;
  display: flex;
  align-items: center
}

.luckysheet-zoom-content .luckysheet-zoom-slider .luckysheet-zoom-line {
  position: absolute;
  top: 10px;
  width: 100px;
  height: 2px;
  background: #e1e4e8
}

.luckysheet-zoom-content .luckysheet-zoom-slider .luckysheet-zoom-cursor {
  position: absolute;
  top: 7px;
  width: 8px;
  height: 8px;
  border-radius: 8px;
  background: #b5bdb8;
  cursor: pointer;
  z-index: 2;
  transition: all .3s
}

.luckysheet-zoom-content .luckysheet-zoom-slider .luckysheet-zoom-cursor:hover {
  transform: scale(1.2);
  transform-origin: center center;
  background: #a0a0a0
}

.luckysheet-zoom-content .luckysheet-zoom-slider .luckysheet-zoom-hundred {
  position: absolute;
  top: 9px;
  width: 2px;
  height: 4px;
  left: 49px;
  background: #1e1e1f
}

.luckysheet-zoom-content .luckysheet-zoom-plus {
  position: absolute;
  top: 0;
  left: 130px;
  width: 20px;
  height: 20px;
  cursor: pointer;
  display: flex;
  align-items: center;
  justify-content: center
}

.luckysheet-zoom-content .luckysheet-zoom-plus .luckysheet-zoom-plus-icon {
  background-image: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB3aWR0aD0iMTRweCIgaGVpZ2h0PSIxNHB4IiB2aWV3Qm94PSIwIDAgMTQgMTQiIHZlcnNpb249IjEuMSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayI+CiAgICA8IS0tIEdlbmVyYXRvcjogU2tldGNoIDYzICg5MjQ0NSkgLSBodHRwczovL3NrZXRjaC5jb20gLS0+CiAgICA8dGl0bGU+cmlxaXF1amlhbuWkh+S7vSA0NjwvdGl0bGU+CiAgICA8ZGVzYz5DcmVhdGVkIHdpdGggU2tldGNoLjwvZGVzYz4KICAgIDxnIGlkPSIyMDIwLzA4LzE0IiBzdHJva2U9Im5vbmUiIHN0cm9rZS13aWR0aD0iMSIgZmlsbD0ibm9uZSIgZmlsbC1ydWxlPSJldmVub2RkIj4KICAgICAgICA8ZyBpZD0i55S75p2/5aSH5Lu9LTIiIHRyYW5zZm9ybT0idHJhbnNsYXRlKC0xODQ4LjAwMDAwMCwgLTEwNTguMDAwMDAwKSIgZmlsbD0iIzQ0NEQ1QSI+CiAgICAgICAgICAgIDxnIGlkPSJyaXFpcXVqaWFu5aSH5Lu9LTExOSIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoMTg0My4wMDAwMDAsIDEwNTMuMDAwMDAwKSI+CiAgICAgICAgICAgICAgICA8ZyBpZD0i57yW57uEIiB0cmFuc2Zvcm09InRyYW5zbGF0ZSg1LjAwMDAwMCwgNS4wMDAwMDApIj4KICAgICAgICAgICAgICAgICAgICA8cmVjdCBpZD0i55+p5b2iIiB4PSIwIiB5PSI2IiB3aWR0aD0iMTQiIGhlaWdodD0iMiI+PC9yZWN0PgogICAgICAgICAgICAgICAgICAgIDxyZWN0IGlkPSLnn6nlvaLlpIfku70iIHRyYW5zZm9ybT0idHJhbnNsYXRlKDcuMDAwMDAwLCA3LjAwMDAwMCkgcm90YXRlKC0yNzAuMDAwMDAwKSB0cmFuc2xhdGUoLTcuMDAwMDAwLCAtNy4wMDAwMDApICIgeD0iMCIgeT0iNiIgd2lkdGg9IjE0IiBoZWlnaHQ9IjIiPjwvcmVjdD4KICAgICAgICAgICAgICAgIDwvZz4KICAgICAgICAgICAgPC9nPgogICAgICAgIDwvZz4KICAgIDwvZz4KPC9zdmc+);
  width: 14px;
  height: 14px
}

.luckysheet-zoom-content .luckysheet-zoom-plus:hover {
  background-color: #e1e4e8
}

.luckysheet-zoom-content .luckysheet-zoom-ratioText {
  position: absolute;
  top: 0;
  left: 155px;
  width: 60px;
  color: #1e1e1f;
  font-size: 12px;
  text-align: left;
  cursor: pointer
}

.luckysheet-zoom-content .luckysheet-zoom-ratioText:hover {
  background-color: #e1e4e8
}

.flatpickr-calendar {
  background: 0 0;
  opacity: 0;
  display: none;
  text-align: center;
  visibility: hidden;
  padding: 0;
  -webkit-animation: none;
  animation: none;
  direction: ltr;
  border: 0;
  font-size: 14px;
  line-height: 24px;
  border-radius: 5px;
  position: absolute;
  width: 307.875px;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  -ms-touch-action: manipulation;
  touch-action: manipulation;
  -webkit-box-shadow: 0 3px 13px rgba(0,0,0,.08);
  box-shadow: 0 3px 13px rgba(0,0,0,.08)
}

.flatpickr-calendar.inline,.flatpickr-calendar.open {
  opacity: 1;
  max-height: 640px;
  visibility: visible
}

.flatpickr-calendar.open {
  display: inline-block;
  z-index: 99999
}

.flatpickr-calendar.animate.open {
  -webkit-animation: fpFadeInDown .3s cubic-bezier(.23,1,.32,1);
  animation: fpFadeInDown .3s cubic-bezier(.23,1,.32,1)
}

.flatpickr-calendar.inline {
  display: block;
  position: relative;
  top: 2px
}

.flatpickr-calendar.static {
  position: absolute;
  top: calc(100% + 2px)
}

.flatpickr-calendar.static.open {
  z-index: 999;
  display: block
}

.flatpickr-calendar.multiMonth .flatpickr-days .dayContainer:nth-child(n+1) .flatpickr-day.inRange:nth-child(7n+7) {
  -webkit-box-shadow: none!important;
  box-shadow: none!important
}

.flatpickr-calendar.multiMonth .flatpickr-days .dayContainer:nth-child(n+2) .flatpickr-day.inRange:nth-child(7n+1) {
  -webkit-box-shadow: -2px 0 0 #e6e6e6,5px 0 0 #e6e6e6;
  box-shadow: -2px 0 0 #e6e6e6,5px 0 0 #e6e6e6
}

.flatpickr-calendar .hasTime .dayContainer,.flatpickr-calendar .hasWeeks .dayContainer {
  border-bottom: 0;
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0
}

.flatpickr-calendar .hasWeeks .dayContainer {
  border-left: 0
}

.flatpickr-calendar.hasTime .flatpickr-time {
  height: 40px;
  border-top: 1px solid #eceef1
}

.flatpickr-calendar.hasTime .flatpickr-innerContainer {
  border-bottom: 0
}

.flatpickr-calendar.hasTime .flatpickr-time {
  border: 1px solid #eceef1
}

.flatpickr-calendar.noCalendar.hasTime .flatpickr-time {
  height: auto
}

.flatpickr-calendar:after,.flatpickr-calendar:before {
  position: absolute;
  display: block;
  pointer-events: none;
  border: solid transparent;
  content: '';
  height: 0;
  width: 0;
  left: 22px
}

.flatpickr-calendar.arrowRight:after,.flatpickr-calendar.arrowRight:before,.flatpickr-calendar.rightMost:after,.flatpickr-calendar.rightMost:before {
  left: auto;
  right: 22px
}

.flatpickr-calendar.arrowCenter:after,.flatpickr-calendar.arrowCenter:before {
  left: 50%;
  right: 50%
}

.flatpickr-calendar:before {
  border-width: 5px;
  margin: 0 -5px
}

.flatpickr-calendar:after {
  border-width: 4px;
  margin: 0 -4px
}

.flatpickr-calendar.arrowTop:after,.flatpickr-calendar.arrowTop:before {
  bottom: 100%
}

.flatpickr-calendar.arrowTop:before {
  border-bottom-color: #eceef1
}

.flatpickr-calendar.arrowTop:after {
  border-bottom-color: #eceef1
}

.flatpickr-calendar.arrowBottom:after,.flatpickr-calendar.arrowBottom:before {
  top: 100%
}

.flatpickr-calendar.arrowBottom:before {
  border-top-color: #eceef1
}

.flatpickr-calendar.arrowBottom:after {
  border-top-color: #eceef1
}

.flatpickr-calendar:focus {
  outline: 0
}

.flatpickr-wrapper {
  position: relative;
  display: inline-block
}

.flatpickr-months {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex
}

.flatpickr-months .flatpickr-month {
  border-radius: 5px 5px 0 0;
  background: #eceef1;
  color: #5a6171;
  fill: #5a6171;
  height: 34px;
  line-height: 1;
  text-align: center;
  position: relative;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  overflow: hidden;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1
}

.flatpickr-months .flatpickr-next-month,.flatpickr-months .flatpickr-prev-month {
  text-decoration: none;
  cursor: pointer;
  position: absolute;
  top: 0;
  height: 34px;
  padding: 10px;
  z-index: 3;
  color: #5a6171;
  fill: #5a6171
}

.flatpickr-months .flatpickr-next-month.flatpickr-disabled,.flatpickr-months .flatpickr-prev-month.flatpickr-disabled {
  display: none
}

.flatpickr-months .flatpickr-next-month i,.flatpickr-months .flatpickr-prev-month i {
  position: relative
}

.flatpickr-months .flatpickr-next-month.flatpickr-prev-month,.flatpickr-months .flatpickr-prev-month.flatpickr-prev-month {
  left: 0
}

.flatpickr-months .flatpickr-next-month.flatpickr-next-month,.flatpickr-months .flatpickr-prev-month.flatpickr-next-month {
  right: 0
}

.flatpickr-months .flatpickr-next-month:hover,.flatpickr-months .flatpickr-prev-month:hover {
  color: #bbb
}

.flatpickr-months .flatpickr-next-month:hover svg,.flatpickr-months .flatpickr-prev-month:hover svg {
  fill: #f64747
}

.flatpickr-months .flatpickr-next-month svg,.flatpickr-months .flatpickr-prev-month svg {
  width: 14px;
  height: 14px
}

.flatpickr-months .flatpickr-next-month svg path,.flatpickr-months .flatpickr-prev-month svg path {
  -webkit-transition: fill .1s;
  transition: fill .1s;
  fill: inherit
}

.numInputWrapper {
  position: relative;
  height: auto
}

.numInputWrapper input,.numInputWrapper span {
  display: inline-block
}

.numInputWrapper input {
  width: 100%
}

.numInputWrapper input::-ms-clear {
  display: none
}

.numInputWrapper input::-webkit-inner-spin-button,.numInputWrapper input::-webkit-outer-spin-button {
  margin: 0;
  -webkit-appearance: none
}

.numInputWrapper span {
  position: absolute;
  right: 0;
  width: 14px;
  padding: 0 4px 0 2px;
  height: 50%;
  line-height: 50%;
  opacity: 0;
  cursor: pointer;
  border: 1px solid rgba(72,72,72,.15);
  -webkit-box-sizing: border-box;
  box-sizing: border-box
}

.numInputWrapper span:hover {
  background: rgba(0,0,0,.1)
}

.numInputWrapper span:active {
  background: rgba(0,0,0,.2)
}

.numInputWrapper span:after {
  display: block;
  content: "";
  position: absolute
}

.numInputWrapper span.arrowUp {
  top: 0;
  border-bottom: 0
}

.numInputWrapper span.arrowUp:after {
  border-left: 4px solid transparent;
  border-right: 4px solid transparent;
  border-bottom: 4px solid rgba(72,72,72,.6);
  top: 26%
}

.numInputWrapper span.arrowDown {
  top: 50%
}

.numInputWrapper span.arrowDown:after {
  border-left: 4px solid transparent;
  border-right: 4px solid transparent;
  border-top: 4px solid rgba(72,72,72,.6);
  top: 40%
}

.numInputWrapper span svg {
  width: inherit;
  height: auto
}

.numInputWrapper span svg path {
  fill: rgba(90,97,113,.5)
}

.numInputWrapper:hover {
  background: rgba(0,0,0,.05)
}

.numInputWrapper:hover span {
  opacity: 1
}

.flatpickr-current-month {
  font-size: 135%;
  line-height: inherit;
  font-weight: 300;
  color: inherit;
  position: absolute;
  width: 75%;
  left: 12.5%;
  padding: 7.48px 0 0 0;
  line-height: 1;
  height: 34px;
  display: inline-block;
  text-align: center;
  -webkit-transform: translate3d(0,0,0);
  transform: translate3d(0,0,0)
}

.flatpickr-current-month span.cur-month {
  font-family: inherit;
  font-weight: 700;
  color: inherit;
  display: inline-block;
  margin-left: .5ch;
  padding: 0
}

.flatpickr-current-month span.cur-month:hover {
  background: rgba(0,0,0,.05)
}

.flatpickr-current-month .numInputWrapper {
  width: 6ch;
  display: inline-block
}

.flatpickr-current-month .numInputWrapper span.arrowUp:after {
  border-bottom-color: #5a6171
}

.flatpickr-current-month .numInputWrapper span.arrowDown:after {
  border-top-color: #5a6171
}

.flatpickr-current-month input.cur-year {
  background: 0 0;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  color: inherit;
  cursor: text;
  padding: 0 0 0 .5ch;
  margin: 0;
  display: inline-block;
  font-size: inherit;
  font-family: inherit;
  font-weight: 300;
  line-height: inherit;
  height: auto;
  border: 0;
  border-radius: 0;
  vertical-align: initial;
  -webkit-appearance: textfield;
  -moz-appearance: textfield;
  appearance: textfield
}

.flatpickr-current-month input.cur-year:focus {
  outline: 0
}

.flatpickr-current-month input.cur-year[disabled],.flatpickr-current-month input.cur-year[disabled]:hover {
  font-size: 100%;
  color: rgba(90,97,113,.5);
  background: 0 0;
  pointer-events: none
}

.flatpickr-current-month .flatpickr-monthDropdown-months {
  appearance: menulist;
  background: #eceef1;
  border: none;
  border-radius: 0;
  box-sizing: border-box;
  color: inherit;
  cursor: pointer;
  font-size: inherit;
  font-family: inherit;
  font-weight: 300;
  height: auto;
  line-height: inherit;
  margin: -1px 0 0 0;
  outline: 0;
  padding: 0 0 0 .5ch;
  position: relative;
  vertical-align: initial;
  -webkit-box-sizing: border-box;
  -webkit-appearance: menulist;
  -moz-appearance: menulist;
  width: auto
}

.flatpickr-current-month .flatpickr-monthDropdown-months:active,.flatpickr-current-month .flatpickr-monthDropdown-months:focus {
  outline: 0
}

.flatpickr-current-month .flatpickr-monthDropdown-months:hover {
  background: rgba(0,0,0,.05)
}

.flatpickr-current-month .flatpickr-monthDropdown-months .flatpickr-monthDropdown-month {
  background-color: #eceef1;
  outline: 0;
  padding: 0
}

.flatpickr-weekdays {
  background: #eceef1;
  text-align: center;
  overflow: hidden;
  width: 100%;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  height: 28px
}

.flatpickr-weekdays .flatpickr-weekdaycontainer {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1
}

span.flatpickr-weekday {
  cursor: default;
  font-size: 90%;
  background: #eceef1;
  color: #5a6171;
  line-height: 1;
  margin: 0;
  text-align: center;
  display: block;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  font-weight: bolder
}

.dayContainer,.flatpickr-weeks {
  padding: 1px 0 0 0
}

.flatpickr-days {
  position: relative;
  overflow: hidden;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  width: 307.875px;
  border-left: 1px solid #eceef1;
  border-right: 1px solid #eceef1
}

.flatpickr-days:focus {
  outline: 0
}

.dayContainer {
  padding: 0;
  outline: 0;
  text-align: left;
  width: 307.875px;
  min-width: 307.875px;
  max-width: 307.875px;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  display: inline-block;
  display: -ms-flexbox;
  display: -webkit-box;
  display: -webkit-flex;
  display: flex;
  -webkit-flex-wrap: wrap;
  flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  -ms-flex-pack: justify;
  -webkit-justify-content: space-around;
  justify-content: space-around;
  -webkit-transform: translate3d(0,0,0);
  transform: translate3d(0,0,0);
  opacity: 1
}

.dayContainer+.dayContainer {
  -webkit-box-shadow: -1px 0 0 #eceef1;
  box-shadow: -1px 0 0 #eceef1
}

.flatpickr-day {
  background: 0 0;
  border: 1px solid transparent;
  border-radius: 150px;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  color: #484848;
  cursor: pointer;
  font-weight: 400;
  width: 14.2857143%;
  -webkit-flex-basis: 14.2857143%;
  -ms-flex-preferred-size: 14.2857143%;
  flex-basis: 14.2857143%;
  max-width: 39px;
  height: 39px;
  line-height: 39px;
  margin: 0;
  display: inline-block;
  position: relative;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  text-align: center
}

.flatpickr-day.inRange,.flatpickr-day.nextMonthDay.inRange,.flatpickr-day.nextMonthDay.today.inRange,.flatpickr-day.nextMonthDay:focus,.flatpickr-day.nextMonthDay:hover,.flatpickr-day.prevMonthDay.inRange,.flatpickr-day.prevMonthDay.today.inRange,.flatpickr-day.prevMonthDay:focus,.flatpickr-day.prevMonthDay:hover,.flatpickr-day.today.inRange,.flatpickr-day:focus,.flatpickr-day:hover {
  cursor: pointer;
  outline: 0;
  background: #e2e2e2;
  border-color: #e2e2e2
}

.flatpickr-day.today {
  border-color: #bbb
}

.flatpickr-day.today:focus,.flatpickr-day.today:hover {
  border-color: #bbb;
  background: #bbb;
  color: #fff
}

.flatpickr-day.endRange,.flatpickr-day.endRange.inRange,.flatpickr-day.endRange.nextMonthDay,.flatpickr-day.endRange.prevMonthDay,.flatpickr-day.endRange:focus,.flatpickr-day.endRange:hover,.flatpickr-day.selected,.flatpickr-day.selected.inRange,.flatpickr-day.selected.nextMonthDay,.flatpickr-day.selected.prevMonthDay,.flatpickr-day.selected:focus,.flatpickr-day.selected:hover,.flatpickr-day.startRange,.flatpickr-day.startRange.inRange,.flatpickr-day.startRange.nextMonthDay,.flatpickr-day.startRange.prevMonthDay,.flatpickr-day.startRange:focus,.flatpickr-day.startRange:hover {
  background: #ff5a5f;
  -webkit-box-shadow: none;
  box-shadow: none;
  color: #fff;
  border-color: #ff5a5f
}

.flatpickr-day.endRange.startRange,.flatpickr-day.selected.startRange,.flatpickr-day.startRange.startRange {
  border-radius: 50px 0 0 50px
}

.flatpickr-day.endRange.endRange,.flatpickr-day.selected.endRange,.flatpickr-day.startRange.endRange {
  border-radius: 0 50px 50px 0
}

.flatpickr-day.endRange.startRange+.endRange:not(:nth-child(7n+1)),.flatpickr-day.selected.startRange+.endRange:not(:nth-child(7n+1)),.flatpickr-day.startRange.startRange+.endRange:not(:nth-child(7n+1)) {
  -webkit-box-shadow: -10px 0 0 #ff5a5f;
  box-shadow: -10px 0 0 #ff5a5f
}

.flatpickr-day.endRange.startRange.endRange,.flatpickr-day.selected.startRange.endRange,.flatpickr-day.startRange.startRange.endRange {
  border-radius: 50px
}

.flatpickr-day.inRange {
  border-radius: 0;
  -webkit-box-shadow: -5px 0 0 #e2e2e2,5px 0 0 #e2e2e2;
  box-shadow: -5px 0 0 #e2e2e2,5px 0 0 #e2e2e2
}

.flatpickr-day.flatpickr-disabled,.flatpickr-day.flatpickr-disabled:hover,.flatpickr-day.nextMonthDay,.flatpickr-day.notAllowed,.flatpickr-day.notAllowed.nextMonthDay,.flatpickr-day.notAllowed.prevMonthDay,.flatpickr-day.prevMonthDay {
  color: rgba(72,72,72,.3);
  background: 0 0;
  border-color: transparent;
  cursor: default
}

.flatpickr-day.flatpickr-disabled,.flatpickr-day.flatpickr-disabled:hover {
  cursor: not-allowed;
  color: rgba(72,72,72,.1)
}

.flatpickr-day.week.selected {
  border-radius: 0;
  -webkit-box-shadow: -5px 0 0 #ff5a5f,5px 0 0 #ff5a5f;
  box-shadow: -5px 0 0 #ff5a5f,5px 0 0 #ff5a5f
}

.flatpickr-day.hidden {
  visibility: hidden
}

.rangeMode .flatpickr-day {
  margin-top: 1px
}

.flatpickr-weekwrapper {
  float: left
}

.flatpickr-weekwrapper .flatpickr-weeks {
  padding: 0 12px;
  border-left: 1px solid #eceef1
}

.flatpickr-weekwrapper .flatpickr-weekday {
  float: none;
  width: 100%;
  line-height: 28px
}

.flatpickr-weekwrapper span.flatpickr-day,.flatpickr-weekwrapper span.flatpickr-day:hover {
  display: block;
  width: 100%;
  max-width: none;
  color: rgba(72,72,72,.3);
  background: 0 0;
  cursor: default;
  border: none
}

.flatpickr-innerContainer {
  display: block;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  overflow: hidden;
  background: #fff;
  border-bottom: 1px solid #eceef1
}

.flatpickr-rContainer {
  display: inline-block;
  padding: 0;
  -webkit-box-sizing: border-box;
  box-sizing: border-box
}

.flatpickr-time {
  text-align: center;
  outline: 0;
  display: block;
  height: 0;
  line-height: 40px;
  max-height: 40px;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  overflow: hidden;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  background: #fff;
  border-radius: 0 0 5px 5px
}

.flatpickr-time:after {
  content: "";
  display: table;
  clear: both
}

.flatpickr-time .numInputWrapper {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  width: 40%;
  height: 40px;
  float: left
}

.flatpickr-time .numInputWrapper span.arrowUp:after {
  border-bottom-color: #484848
}

.flatpickr-time .numInputWrapper span.arrowDown:after {
  border-top-color: #484848
}

.flatpickr-time.hasSeconds .numInputWrapper {
  width: 26%
}

.flatpickr-time.time24hr .numInputWrapper {
  width: 49%
}

.flatpickr-time input {
  background: 0 0;
  -webkit-box-shadow: none;
  box-shadow: none;
  border: 0;
  border-radius: 0;
  text-align: center;
  margin: 0;
  padding: 0;
  height: inherit;
  line-height: inherit;
  color: #484848;
  font-size: 14px;
  position: relative;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-appearance: textfield;
  -moz-appearance: textfield;
  appearance: textfield
}

.flatpickr-time input.flatpickr-hour {
  font-weight: 700
}

.flatpickr-time input.flatpickr-minute,.flatpickr-time input.flatpickr-second {
  font-weight: 400
}

.flatpickr-time input:focus {
  outline: 0;
  border: 0
}

.flatpickr-time .flatpickr-am-pm,.flatpickr-time .flatpickr-time-separator {
  height: inherit;
  float: left;
  line-height: inherit;
  color: #484848;
  font-weight: 700;
  width: 2%;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  -webkit-align-self: center;
  -ms-flex-item-align: center;
  align-self: center
}

.flatpickr-time .flatpickr-am-pm {
  outline: 0;
  width: 18%;
  cursor: pointer;
  text-align: center;
  font-weight: 400
}

.flatpickr-time .flatpickr-am-pm:focus,.flatpickr-time .flatpickr-am-pm:hover,.flatpickr-time input:focus,.flatpickr-time input:hover {
  background: #eaeaea
}

.flatpickr-input[readonly] {
  cursor: pointer
}

@-webkit-keyframes fpFadeInDown {
  from {
      opacity: 0;
      -webkit-transform: translate3d(0,-20px,0);
      transform: translate3d(0,-20px,0)
  }

  to {
      opacity: 1;
      -webkit-transform: translate3d(0,0,0);
      transform: translate3d(0,0,0)
  }
}

@keyframes fpFadeInDown {
  from {
      opacity: 0;
      -webkit-transform: translate3d(0,-20px,0);
      transform: translate3d(0,-20px,0)
  }

  to {
      opacity: 1;
      -webkit-transform: translate3d(0,0,0);
      transform: translate3d(0,0,0)
  }
}

span.flatpickr-day.selected {
  font-weight: 700
}
